<?php
/*
 * @version $Id: fr_FR.php 13713 2011-01-24 09:53:28Z yllen $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 --------------------------------------------------------------------------
 */
//fr_FR

$LANG = array();

$LANG['backup'][0]  = "Sauvegarde SQL";
$LANG['backup'][1]  = "Sauvegarde XML";

$LANG['backup'][11] = "Taille";

$LANG['backup'][13] = "Voir/Télécharger";

$LANG['backup'][16] = "Remplacer la base de données actuelle par le fichier de sauvegarde :";
$LANG['backup'][17] = "Supprimer le fichier";
$LANG['backup'][18] = "Sauvegarder la base de données";
$LANG['backup'][19] = "Maintenant";
$LANG['backup'][21] = "Le fichier existe déjà";
$LANG['backup'][22] = "Impossible de trouver l'octet";
$LANG['backup'][23] = "Erreur MySQL à partir de";
$LANG['backup'][24] = "Redirection automatique, sinon cliquez";


$LANG['bookmark'][1] = "marque-page";
$LANG['bookmark'][2] = "Chargement partiel du marque-page.";
$LANG['bookmark'][3] = "Vous n'avez pas encore enregistré de marque-pages.";
$LANG['bookmark'][4] = "Nouveau marque-page";
$LANG['bookmark'][5] = "Marque-pages publics";
$LANG['bookmark'][6] = "Vue par défaut";


$LANG['buttons'][0]  = "Rechercher";

$LANG['buttons'][2]  = "Valider";
$LANG['buttons'][3]  = "Associer";
$LANG['buttons'][4]  = "Installer";
$LANG['buttons'][5]  = "Désinstaller";
$LANG['buttons'][6]  = "Supprimer";
$LANG['buttons'][7]  = "Actualiser";
$LANG['buttons'][8]  = "Ajouter";
$LANG['buttons'][9]  = "Connecter";
$LANG['buttons'][10] = "Déconnecter";
$LANG['buttons'][11] = "Suivant";
$LANG['buttons'][12] = "Précédent";
$LANG['buttons'][13] = "Retour";
$LANG['buttons'][14] = "Modifier";
$LANG['buttons'][15] = "Calendrier";
$LANG['buttons'][16] = "Raz";
$LANG['buttons'][17] = "Inverser la sélection";
$LANG['buttons'][18] = "Tout cocher";
$LANG['buttons'][19] = "Tout décocher";
$LANG['buttons'][20] = "Déplacer";
$LANG['buttons'][21] = "Restaurer";
$LANG['buttons'][22] = "Purger";
$LANG['buttons'][23] = "Voir";
$LANG['buttons'][24] = "Monter";
$LANG['buttons'][25] = "Descendre";

$LANG['buttons'][27] = "Page courante en PDF";
$LANG['buttons'][28] = "Page courante en SLK";
$LANG['buttons'][29] = "Toutes les pages en PDF";
$LANG['buttons'][30] = "Toutes les pages en SLK";
$LANG['buttons'][31] = "Exporter";
$LANG['buttons'][32] = "Fin";
$LANG['buttons'][33] = "Début";
$LANG['buttons'][34] = "Annuler";

$LANG['buttons'][37] = "Importer";
$LANG['buttons'][38] = "Déverrouiller";
$LANG['buttons'][39] = "Remplacer";
$LANG['buttons'][40] = "Voir tous";
$LANG['buttons'][41] = "Activer";
$LANG['buttons'][42] = "Désactiver";
$LANG['buttons'][43] = "Naviguer";
$LANG['buttons'][44] = "Page courante en CSV";
$LANG['buttons'][45] = "Toutes les pages en CSV";
$LANG['buttons'][46] = "Avant";
$LANG['buttons'][47] = "Après";
$LANG['buttons'][48] = "Transférer";
$LANG['buttons'][49] = "Conserver";
$LANG['buttons'][50] = "Tester";
$LANG['buttons'][51] = "Enregistrer";
$LANG['buttons'][52] = "Charger";
$LANG['buttons'][53] = "Nettoyer";

$LANG['buttons'][55] = "Premier";
$LANG['buttons'][56] = "Dernier";
$LANG['buttons'][57] = "Exécuter";
$LANG['buttons'][58] = "Mettre à jour";
$LANG['buttons'][59] = "Dissocier";

$LANG['calendar'][0] = "AAAA-MM-JJ";
$LANG['calendar'][1] = "JJ-MM-AAAA";
$LANG['calendar'][2] = "MM-JJ-AAAA";

$LANG['calendarD'][0] = "D";
$LANG['calendarD'][1] = "L";
$LANG['calendarD'][2] = "M";
$LANG['calendarD'][3] = "M";
$LANG['calendarD'][4] = "J";
$LANG['calendarD'][5] = "V";
$LANG['calendarD'][6] = "S";


$LANG['calendarDay'][0] = "Dimanche";
$LANG['calendarDay'][1] = "Lundi";
$LANG['calendarDay'][2] = "Mardi";
$LANG['calendarDay'][3] = "Mercredi";
$LANG['calendarDay'][4] = "Jeudi";
$LANG['calendarDay'][5] = "Vendredi";
$LANG['calendarDay'][6] = "Samedi";


$LANG['calendarM'][0]  = "Janvier";
$LANG['calendarM'][1]  = "Février";
$LANG['calendarM'][2]  = "Mars";
$LANG['calendarM'][3]  = "Avril";
$LANG['calendarM'][4]  = "Mai";
$LANG['calendarM'][5]  = "Juin";
$LANG['calendarM'][6]  = "Juillet";
$LANG['calendarM'][7]  = "Août";
$LANG['calendarM'][8]  = "Septembre";
$LANG['calendarM'][9]  = "Octobre";
$LANG['calendarM'][10] = "Novembre";
$LANG['calendarM'][11] = "Décembre";


$LANG['cartridges'][0]  = "Cartouche";

$LANG['cartridges'][7]  = "Pas de cartouche trouvée";

$LANG['cartridges'][9]  = "Aucune cartouche";
$LANG['cartridges'][10] = "Toner";
$LANG['cartridges'][11] = "Jet d'encre";
$LANG['cartridges'][12] = "Type de cartouche";
$LANG['cartridges'][13] = "Neuve(s)";
$LANG['cartridges'][14] = "Utilisée(s)";
$LANG['cartridges'][15] = "Usagée(s)";
$LANG['cartridges'][16] = "Cartouche(s)";

$LANG['cartridges'][20] ="Neuve";
$LANG['cartridges'][21] ="Utilisée";
$LANG['cartridges'][22] ="Usagée";

$LANG['cartridges'][24] = "Date ajout";

$LANG['cartridges'][27] = "Sur";

$LANG['cartridges'][29] = "Fin de vie";

$LANG['cartridges'][32] = "Modèles d'imprimantes compatibles";
$LANG['cartridges'][33] = "Cartouches utilisées";
$LANG['cartridges'][34] = "Pas de cartouche libre";
$LANG['cartridges'][35] = "Cartouche(s) usagée(s)";

$LANG['cartridges'][37] = "Ruban";

$LANG['cartridges'][39] = "Compteur imprimante";
$LANG['cartridges'][40] = "En stock en moyenne";
$LANG['cartridges'][41] = "Utilisation moyenne";
$LANG['cartridges'][42] = "Pages imprimées en moyenne";


$LANG['central'][2]  = "Derniers";

$LANG['central'][4]  = "Pas d'événement";
$LANG['central'][5]  = "Accueil";
$LANG['central'][6]  = "Déconnexion";
$LANG['central'][7]  = "Aide";
$LANG['central'][8]  = "Ajouts";
$LANG['central'][9]  = "Vos tickets en cours";
$LANG['central'][10] ="Les nouveaux tickets";

$LANG['central'][12] = "Vue personnelle";
$LANG['central'][13] = "Vue globale";
$LANG['central'][14] = "Vue groupe";

$LANG['central'][18] = "Vos tickets à clore";
$LANG['central'][19] = "Vos tickets à valider";

$LANG['choice'][0] = "Non";
$LANG['choice'][1] = "Oui";


$LANG['common'][0]  = "Sans nom";
$LANG['common'][1]  = "Matériel";
$LANG['common'][2]  = "ID";
$LANG['common'][3]  = "Voir la corbeille";
$LANG['common'][4]  = "Web";
$LANG['common'][5]  = "Fabricant";
$LANG['common'][6]  = "Nom du gabarit";
$LANG['common'][7]  = "Choisissez un gabarit";
$LANG['common'][8]  = "Gérer Gabarits...";
$LANG['common'][9]  = "Ajouter un gabarit...";
$LANG['common'][10] = "Responsable technique";
$LANG['common'][11] = "Affichage limité";
$LANG['common'][12] = "Configuration";
$LANG['common'][13] = "Gabarit";
$LANG['common'][14] = "Gabarits";
$LANG['common'][15] = "Lieu";
$LANG['common'][16] = "Nom";
$LANG['common'][17] = "Type";
$LANG['common'][18] = "Usager";
$LANG['common'][19] = "Numéro de série";
$LANG['common'][20] = "Numéro d'inventaire";
$LANG['common'][21] = "Usager numéro";
$LANG['common'][22] = "Modèle";
$LANG['common'][23] = "Opération réalisée avec succès";
$LANG['common'][24] = "Aucun élément sélectionné ou opération mal définie";
$LANG['common'][25] = "Commentaires";
$LANG['common'][26] = "Dernière modification";
$LANG['common'][27] = "Date";
$LANG['common'][28] = "Supprimé";
$LANG['common'][29] = "Plugins";
$LANG['common'][30] = "Nouvel item";
$LANG['common'][31] = "Gabarit vide";
$LANG['common'][32] = "Caractéristiques";
$LANG['common'][33] = "Total";
$LANG['common'][34] = "Utilisateur";
$LANG['common'][35] = "Groupe";
$LANG['common'][36] = "Catégorie";
$LANG['common'][37] = "Rédacteur";
$LANG['common'][38] = "Passer en gestion unitaire";
$LANG['common'][39] = "Duplique l'élément autant de fois qu'il y a de connexions";
$LANG['common'][40] = "Êtes-vous sûr de vouloir passer cet élément en gestion unitaire ?";
$LANG['common'][41] = "Alertes par courriel";
$LANG['common'][42] = "Téléphone mobile";
$LANG['common'][43] = "Prénom";
$LANG['common'][44] = "Valeur(s) par défaut";
$LANG['common'][45] = "Mio max";
$LANG['common'][46] = "vCard";
$LANG['common'][47] = "Progression";
$LANG['common'][48] = "Nom de famille";
$LANG['common'][49] = "Aucun";
$LANG['common'][50] = "Confirmer la suppression définitive ?";
$LANG['common'][51] = "Nom complet";
$LANG['common'][52] = "Serveur";
$LANG['common'][53] = "Liste";
$LANG['common'][54] = "Élément introuvable";
$LANG['common'][55] = "Êtes-vous certain de vouloir supprimer cet élément ?";
$LANG['common'][56] = "Interface standard";
$LANG['common'][57] = "Titre";
$LANG['common'][58] = "Valeur maximale";
$LANG['common'][59] = "Global";
$LANG['common'][60] = "Actif";
$LANG['common'][61] = "Erreur inconnue";
$LANG['common'][62] = "Autre";
$LANG['common'][63] = "Erreur(s)";
$LANG['common'][64] = "Superviseur";
$LANG['common'][65] = "Interface";
$LANG['common'][66] = "Tous";
$LANG['common'][67] = "Autres";
$LANG['common'][68] = "Paysage";
$LANG['common'][69] = "Portrait";
$LANG['common'][70] = "Élément ajouté avec succès";
$LANG['common'][71] = "Élément modifié avec succès";
$LANG['common'][72] = "Élément mis à la corbeille avec succès";
$LANG['common'][73] = "Élément supprimé définitivement avec succès";
$LANG['common'][74] = "Élément restauré avec succès";
$LANG['common'][75] = "Pas le droit de rendre cet élément récursif pour cette entité";
$LANG['common'][76] = "Public";
$LANG['common'][77] = "Privé";
$LANG['common'][78] = "Rendre public";
$LANG['common'][79] = "Rendre personnel";
$LANG['common'][80] = "En cours de chargement...";
$LANG['common'][81] = "Sortir de la corbeille";
$LANG['common'][82] = "Mio";
$LANG['common'][83] = "Vous n'avez pas les droits requis pour réaliser cette action.";
$LANG['common'][84] = "La présence d'éléments liés interdit la modification de cet attribut";
$LANG['common'][85] = "Modifier la visibilité dans les sous-entités";
$LANG['common'][86] = "Vous n'avez pas les droits requis pour modifier la visibilité dans les sous-entités.";
$LANG['common'][87] = "Nouvelle fiche";
$LANG['common'][88] = "Personnel";
$LANG['common'][89] = "Non installé";
$LANG['common'][90] = "Objet";
$LANG['common'][91] = "Cet élément est dépendant d'un autre. La modification de cet attribut est interdit.";
$LANG['common'][92] = "Contact";
$LANG['common'][93] = "Nouvel intitulé enfant";


$LANG['computers'][0]  = "Volume";
$LANG['computers'][1]  = "Pourcentage libre";
$LANG['computers'][2]  = "Taille libre";
$LANG['computers'][3]  = "Taille totale";
$LANG['computers'][4]  = "Système de fichiers";
$LANG['computers'][5]  = "Point de montage";
$LANG['computers'][6]  = "Partition";
$LANG['computers'][7]  = "Ajouter un volume";
$LANG['computers'][8]  = "Volumes";
$LANG['computers'][9]  = "Système d'exploitation";
$LANG['computers'][10] = "Numéro de série du système d'exploitation";
$LANG['computers'][11] = "Product ID du système d'exploitation";

$LANG['computers'][14] = "Inséré";

$LANG['computers'][23] = "Type de mémoire";
$LANG['computers'][24] = "Mémoire (Mio)";
$LANG['computers'][25] = "Taille du disque dur";

$LANG['computers'][36] = "Type de disque dur";
$LANG['computers'][37] = "Pas de moniteur connecté.";
$LANG['computers'][38] = "Pas d'imprimante connectée";
$LANG['computers'][39] = "Imprimante(s)";
$LANG['computers'][40] = "Moniteur(s)";

$LANG['computers'][46] = "Périphérique(s)";
$LANG['computers'][47] = "Pas de périphérique connecté";
$LANG['computers'][48] = "Modification de lieu. Les éléments connectés ont été déplacés dans le même lieu que l'ordinateur.";
$LANG['computers'][49] = "Modification de l'usager. Les éléments connectés ont pris comme usager celui de l'ordinateur.";
$LANG['computers'][50] = "Modification de l'utilisateur ou du groupe. Les éléments connectés ont été mis à jour avec les mêmes valeurs que l'ordinateur.";
$LANG['computers'][51] = "Source de mise à jour";
$LANG['computers'][52] = "Version du système d'exploitation";
$LANG['computers'][53] = "Service pack";
$LANG['computers'][54] = "Pas de téléphone connecté";
$LANG['computers'][55] = "Téléphone(s)";
$LANG['computers'][56] = "Modification du statut. Les éléments connectés ont été mis à jour avec le statut l'ordinateur.";


$LANG['connect'][0]  = "Connexion(s) directe(s)";
$LANG['connect'][1]  = "Non connecté.";

$LANG['connect'][15] = "Mise à jour automatique des éléments suivants";
$LANG['connect'][16] = "Attention !! Les éléments suivants des deux matériels ne correspondent pas";


$LANG['contract'][0] = "Contrat expiré depuis le";
$LANG['contract'][1] = "Contrat en préavis depuis le";

$LANG['consumables'][0]  = "Consommable";
$LANG['consumables'][1]  = "En stock";
$LANG['consumables'][2]  = "Référence";

$LANG['consumables'][7]  = "Pas de consommable trouvé";

$LANG['consumables'][9]  = "Aucun consommable";

$LANG['consumables'][12] = "Type de consommable";
$LANG['consumables'][13] = "Neuf(s)";

$LANG['consumables'][15] = "Utilisé(s)";
$LANG['consumables'][16] = "Consommable(s)";

$LANG['consumables'][20] = "Neuf";

$LANG['consumables'][22] = "Utilisés";
$LANG['consumables'][23] = "État";

$LANG['consumables'][26] = "Date utilisation";

$LANG['consumables'][32] = "Donner";

$LANG['consumables'][35] = "Consommables utilisés";
$LANG['consumables'][36] = "Lieu de stockage";
$LANG['consumables'][37] = "Réintégrer dans le stock";
$LANG['consumables'][38] = "Seuil d'alerte";


$LANG['crontask'][0]  = "Actions automatiques";
// index if crontask id
$LANG['crontask'][1]  = "Synchronisation des matériels depuis OCSNG";
$LANG['crontask'][2]  = "Envoi des alertes sur les cartouches";
$LANG['crontask'][3]  = "Envoi des alertes sur les consommables";
$LANG['crontask'][4]  = "Envoi des alertes sur les expirations de licences";
$LANG['crontask'][5]  = "Envoi des alertes sur les contrats";
$LANG['crontask'][6]  = "Envoi des alertes sur les informations financières";
$LANG['crontask'][7]  = "Nettoyage des journaux";
$LANG['crontask'][8]  = "Optimisation de la base de données";
$LANG['crontask'][9]  = "Récupération des messages (collecteurs)";
$LANG['crontask'][10] = "Vérification du réplicat MySQL";
$LANG['crontask'][11] = "Vérification de la présence de mises à jour";
$LANG['crontask'][12] = "Nettoyage des sessions expirées";
$LANG['crontask'][13] = "Nettoyage des graphiques générés";
$LANG['crontask'][14] = "Clôture automatique des tickets";
$LANG['crontask'][15] = "Tickets non résolus";

// keep >12 free additionnal task
$LANG['crontask'][31] = "Désactivée";
$LANG['crontask'][32] = "Programmée";
$LANG['crontask'][33] = "En cours d'exécution";
$LANG['crontask'][34] = "GLPI";
$LANG['crontask'][35] = "CLI";
$LANG['crontask'][36] = "Mode d'exécution";
$LANG['crontask'][37] = "Fréquence d'exécution";
$LANG['crontask'][38] = "Plage horaires d'exécution";
$LANG['crontask'][39] = "Nombre de messages à récupérer";
$LANG['crontask'][40] = "Dernière exécution";
$LANG['crontask'][41] = "Prochaine exécution";
$LANG['crontask'][42] = "Dès que possible";
$LANG['crontask'][43] = "Aucune action en attente";
$LANG['crontask'][44] = "Action terminée, traitement partiel";
$LANG['crontask'][45] = "Action terminée, traitement complet";
$LANG['crontask'][46] = "Action terminée, rien à faire";
$LANG['crontask'][47] = "Liste des dernières exécutions";
$LANG['crontask'][48] = "Lancement";

$LANG['crontask'][50] = "Nombre d'exécutions";
$LANG['crontask'][51] = "Durée minimale";
$LANG['crontask'][52] = "Durée maximale";
$LANG['crontask'][53] = "Durée moyenne";

$LANG['crontask'][55] = "Nombre minimum";
$LANG['crontask'][56] = "Nombre maximum";
$LANG['crontask'][57] = "Nombre moyen";
$LANG['crontask'][58] = "Nombre total";
$LANG['crontask'][59] = "Vitesse moyenne";
$LANG['crontask'][60] = "Verrou système";
$LANG['crontask'][61] = "Plugin désactivé";
$LANG['crontask'][62] = "Éléments";


$LANG['devices'][0]  = "Ajouter un nouveau composant";
$LANG['devices'][1]  = "Disque dur";
$LANG['devices'][2]  = "Carte graphique";
$LANG['devices'][3]  = "Carte réseau";
$LANG['devices'][4]  = "Processeur";
$LANG['devices'][5]  = "Carte mère";
$LANG['devices'][6]  = "Mémoire";
$LANG['devices'][7]  = "Carte son";

$LANG['devices'][19] = "Lecteurs";
$LANG['devices'][20] = "Contrôleurs";
$LANG['devices'][21] = "Autres composants";
$LANG['devices'][22] = "Boîtiers";
$LANG['devices'][23] = "Alimentation";
$LANG['devices'][24] = "par défaut";
$LANG['devices'][25] = "Ajout d'un composant";
$LANG['devices'][26] = "Suppression d'un composant";


$LANG['device_case'][0] = "Format";


$LANG['device_control'][0] = "RAID";


$LANG['device_drive'][0] = "Écriture";
$LANG['device_drive'][1] = "Vitesse";

$LANG['device_hdd'][0] = "Rpm";
$LANG['device_hdd'][1] = "Cache";

$LANG['device_hdd'][4] = "Capacité";


$LANG['device_iface'][0] = "Débit";

$LANG['device_iface'][2] = "Adresse Mac";


$LANG['device_moboard'][0]="Chipset";


$LANG['device_power'][0] = "Puissance";
$LANG['device_power'][1] = "ATX";


$LANG['device_ram'][1] = "Fréquence";
$LANG['device_ram'][2] = "Taille";


$LANG['document'][1]  = "Somme de contrôle (SHA1)";
$LANG['document'][2]  = "Fichier";
$LANG['document'][3]  = "Rubrique";
$LANG['document'][4]  = "Type MIME";

$LANG['document'][7]  = "Type de document";

$LANG['document'][9]  = "Extension";
$LANG['document'][10] = "Icône";
$LANG['document'][11] = "Téléchargement autorisé";

$LANG['document'][15] = "Téléchargement";
$LANG['document'][16] = "Ajouter un Document";

$LANG['document'][18] = "Document";
$LANG['document'][19] = "Éléments associés";

$LANG['document'][21] = "Document(s) associé(s)";
$LANG['document'][22] = "Fichier courant";

$LANG['document'][23] = "Fichier trop volumineux pour être ajouté.";
$LANG['document'][24] = "Suppression avec succès du fichier";
$LANG['document'][25] = "Échec de la suppression du fichier";
$LANG['document'][26] = "Le fichier est valide et a été téléchargé avec succès.";
$LANG['document'][27] = "Attaque par upload potentielle. Ou fichier trop volumineux. Impossible de déplacer le fichier temporaire.";
$LANG['document'][28] = "Aucun fichier spécifié.";
$LANG['document'][29] = "Échec de la création du répertoire";
$LANG['document'][30] = "Vérifiez que vous avez les droits";
$LANG['document'][31] = "Répertoire de stockage des documents inexistant :";
$LANG['document'][32] = "Type de fichier non autorisé";
$LANG['document'][33] = "Lien Web";
$LANG['document'][34] = "Création du répertoire";
$LANG['document'][35] = "Répertoire d'upload inexistant";
$LANG['document'][36] = "Sélectionner un fichier installé par FTP";
$LANG['document'][37] = "Pas de fichier disponible";
$LANG['document'][38] = "Fichier introuvable";
$LANG['document'][39] = "Document déplacé avec succès";
$LANG['document'][40] = "Problème dans le déplacement du fichier";
$LANG['document'][41] = "Document copié avec succès";
$LANG['document'][42] = "Ajouté par";
$LANG['document'][43] = "Fichier inconnu";
$LANG['document'][44] = "Nom de fichier incorrect";
$LANG['document'][45] = "Vous n'avez pas le droit d'accéder à ce fichier";
$LANG['document'][46] = "Échec dans l'envoi du fichier (sûrement trop volumineux)";
$LANG['document'][48] = "Un document avec ce fichier est déjà disponible";
$LANG['document'][49] = "Fichier altéré (mauvaise somme de contrôle)";
$LANG['document'][50] = "Élément(s) rattaché(s)";


$LANG['entity'][0]  = "Entité";
$LANG['entity'][2]  = "Entité racine";
$LANG['entity'][3]  = "Associer à une entité";
$LANG['entity'][5]  = "Affectation automatique des ordinateurs";
$LANG['entity'][6]  = "Affectation automatique des utilisateurs";
$LANG['entity'][7]  = "arborescence";
$LANG['entity'][8]  = "Par entité";
$LANG['entity'][9]  = "Sous-entités";
$LANG['entity'][10] = "Sélectionnez l'entité souhaitée";
$LANG['entity'][11] = "pour voir l'entité et ses sous-entités";
$LANG['entity'][12] = "Information LDAP représentant l'entité";
$LANG['entity'][13] = "TAG représentant l'entité";
$LANG['entity'][14] = "Informations avancées";
$LANG['entity'][15] = "Annuaire associé à l'entité";
$LANG['entity'][16] = "Filtre de recherche (si nécessaire)";
$LANG['entity'][17] = "Configuration de la clôture automatique";
$LANG['entity'][18] = "Clôture automatique des tickets résolus après";


$LANG['event'][0]  = "Source";

$LANG['event'][2]  = "Service";
$LANG['event'][3]  = "Niveau";
$LANG['event'][4]  = "Message";

$LANG['event'][18] = "Champ";
$LANG['event'][19] = "Changement";
$LANG['event'][20] = "Pas d'historique";


$LANG['financial'][1]   = "Contrat";
$LANG['financial'][2]   = "A vie";
$LANG['financial'][3]   = "Informations financières";
$LANG['financial'][4]   = "Numéro";
$LANG['financial'][5]   = "Coût";
$LANG['financial'][6]   = "Type de contrat";

$LANG['financial'][8]   = "Durée";
$LANG['financial'][9]   = "an(s)";
$LANG['financial'][10]  = "Préavis";
$LANG['financial'][11]  = "Périodicité de facturation";

$LANG['financial'][13]  = "Numéro comptable";
$LANG['financial'][14]  = "Date d'achat";
$LANG['financial'][15]  = "Durée de garantie";
$LANG['financial'][16]  = "Informations garantie";

$LANG['financial'][18]  = "Numéro de commande";
$LANG['financial'][19]  = "Bon de livraison";
$LANG['financial'][20]  = "Numéro d'immobilisation";
$LANG['financial'][21]  = "Valeur";
$LANG['financial'][22]  = "Type d'amortissement";
$LANG['financial'][23]  = "Durée d'amortissement";
$LANG['financial'][24]  = "Ajouter Contact...";
$LANG['financial'][25]  = "Ajouter Fournisseur...";
$LANG['financial'][26]  = "Fournisseur";

$LANG['financial'][30]  = "Fax";

$LANG['financial'][33]  = "Ajouter un Contact";

$LANG['financial'][36]  = "Ajouter un Contrat";

$LANG['financial'][42]  = "Commercial";
$LANG['financial'][43]  = "Technicien";
$LANG['financial'][44]  = "Adresse";
$LANG['financial'][45]  = "Site Web";
$LANG['financial'][46]  = "Contacts associés";
$LANG['financial'][47]  = "Linéaire";
$LANG['financial'][48]  = "Dégressif";

$LANG['financial'][50]  = "Prêt";
$LANG['financial'][51]  = "Location";
$LANG['financial'][52]  = "Leasing";
$LANG['financial'][53]  = "Assurances";
$LANG['financial'][54]  = "Maintenance Hardware";
$LANG['financial'][55]  = "Maintenance Software";
$LANG['financial'][56]  = "Prestation";
$LANG['financial'][57]  = "mois";

$LANG['financial'][59]  = "Heures d'intervention";
$LANG['financial'][60]  = "en semaine";
$LANG['financial'][61]  = "le samedi";
$LANG['financial'][62]  = "dimanche et fêtes";

$LANG['financial'][65]  = "Fournisseurs associés";
$LANG['financial'][66]  = "Contrats associés";

$LANG['financial'][68]  = "Activer les informations financières";
$LANG['financial'][69]  = "Périodicité du contrat";

$LANG['financial'][76]  = "Date de mise en service";
$LANG['financial'][77]  = "Coefficient d'amortissement";
$LANG['financial'][78]  = "Valeur extension garantie";
$LANG['financial'][79]  = "Type de tiers";
$LANG['financial'][80]  = "Expiration garantie";
$LANG['financial'][81]  = "Valeur nette comptable";
$LANG['financial'][82]  = "Numéro de facture";
$LANG['financial'][83]  = "Nombre max d'éléments";
$LANG['financial'][84]  = "Pour ce type d'élément, les informations financières ne sont qu'un modèle pour les éléments que vous ajouterez ensuite.";
$LANG['financial'][85]  = "Élément demandé introuvable";
$LANG['financial'][86]  = "Expiration contrat";

$LANG['financial'][87]  = "Budget";
$LANG['financial'][88]  = "Expire le :";
$LANG['financial'][89]  = "TCO (valeur+montant des interventions)";
$LANG['financial'][90]  = "TCO mensuel";
$LANG['financial'][91]  = "TCO";
$LANG['financial'][92]  = "VNC";
$LANG['financial'][93]  = "Contrat(s) expiré(s) depuis moins de 30 jours";
$LANG['financial'][94]  = "Contrat(s) qui expire(nt) dans moins de 7 jours";
$LANG['financial'][95]  = "Contrat(s) qui expire(nt) dans moins de 30 jours";
$LANG['financial'][96]  = "Contrat(s) dont le préavis débute dans moins de 7 jours";
$LANG['financial'][97]  = "Contrat(s) dont le préavis débute dans moins de 30 jours";
$LANG['financial'][98]  = "Expiration";
$LANG['financial'][99]  = "Expiration+préavis";
$LANG['financial'][100] = "Code Postal";
$LANG['financial'][101] = "Ville";
$LANG['financial'][102] = "État";
$LANG['financial'][103] = "Pays";
$LANG['financial'][104] = "Matériel rattaché";
$LANG['financial'][105] = "Tacite";
$LANG['financial'][106] = "Express";
$LANG['financial'][107] = "Reconduction";
$LANG['financial'][108] = "Total dépensé sur le budget";
$LANG['financial'][109] = "Total restant sur le budget";
$LANG['financial'][110]  = "Budgets";


$LANG['gmt'][0] = "GMT";
$LANG['gmt'][1] = "heure(s)";
$LANG['gmt'][2] = "h";


// For priority
$LANG['help'][1]  = "Matrice de calcul de la priorité";
$LANG['help'][2]  = "Majeure";
$LANG['help'][3]  = "Très haute";
$LANG['help'][4]  = "Haute";
$LANG['help'][5]  = "Moyenne";
$LANG['help'][6]  = "Basse";
$LANG['help'][7]  = "Très basse";
$LANG['help'][8]  = "Informez-moi des suites données";

$LANG['help'][11] = "Mon adresse de messagerie";
$LANG['help'][14] = "Envoyer message";
$LANG['help'][16] = "Vous voulez être informé des suites données mais vous n'avez pas saisi d'adresse de messagerie.";
$LANG['help'][18] = "Votre demande a bien été enregistrée, son traitement est en cours.";
$LANG['help'][19] = "Merci d'avoir utilisé notre système d'assistance.";
$LANG['help'][22] = "Rechercher votre numéro du matériel";
$LANG['help'][23] = "Saisissez les premières lettres (usager, nom matériel, n° de série ou n° d'inventaire)";
$LANG['help'][24] = "Le ticket porte sur";
$LANG['help'][25] = "Ordinateur";
$LANG['help'][26] = "Matériel réseau";
$LANG['help'][27] = "Imprimante";
$LANG['help'][28] = "Moniteur";
$LANG['help'][29] = "Périphérique";
$LANG['help'][30] = "Général";
$LANG['help'][31] = "Logiciel";
$LANG['help'][35] = "Téléphone";
$LANG['help'][40] = "Votre ticket ne contient pas de titre, veuillez corriger.";
$LANG['help'][41] = "Votre ticket ne contient pas de catégorie, veuillez corriger.";
// For Urgency
$LANG['help'][42] = "Très haute";
$LANG['help'][43] = "Haute";
$LANG['help'][44] = "Moyenne";
$LANG['help'][45] = "Basse";
$LANG['help'][46] = "Très basse";
// For Impact
$LANG['help'][47] = "Très haut";
$LANG['help'][48] = "Haut";
$LANG['help'][49] = "Moyen";
$LANG['help'][50] = "Bas";
$LANG['help'][51] = "Très bas";


$LANG['install'][0]   = "Installation ou mise à jour de GLPI";
$LANG['install'][1]   = "Choisissez 'Installation' pour une nouvelle installation complète de GLPI.";
$LANG['install'][2]   = "Choisissez 'Mise à jour' pour mettre à jour votre version de GLPI à partir d'une version antérieure";
$LANG['install'][3]   = "Installation";
$LANG['install'][4]   = "Mise à jour";
$LANG['install'][5]   = "Vérification de la compatibilité de votre environnement avec l'exécution de GLPI";
$LANG['install'][6]   = "Tests effectués";
$LANG['install'][7]   = "Résultats";
$LANG['install'][8]   = "Test du Parseur PHP";
$LANG['install'][9]   = "Vous devez installer au moins PHP version 5.";
$LANG['install'][10]  = "GLPI n'est pas compatible avec la directive zend.ze1_compatibility_mode = On.";
$LANG['install'][11]  = "La version de PHP est supérieure au minimum requis - Parfait !";
$LANG['install'][12]  = "Test des Sessions";
$LANG['install'][13]  = "Votre parseur PHP n'a pas été compilé avec le support des sessions !";
$LANG['install'][14]  = "Le support des sessions est opérationnel - Parfait !";
$LANG['install'][15]  = "Vérifiez que le support des sessions est bien activé dans votre php.ini";
$LANG['install'][16]  = "Test d'écriture de fichiers dump";
$LANG['install'][17]  = "Le fichier n'a pas pu être créé.";
$LANG['install'][18]  = "Des traductions non officielles sont également disponibles";
$LANG['install'][19]  = "Le fichier a été créé mais n'a pas pu être supprimé.";
$LANG['install'][20]  = "Un fichier et un dossier ont été créés et supprimés - Parfait !";
$LANG['install'][21]  = "Test d'écriture de fichiers documents";
$LANG['install'][22]  = "Un fichier a été créé - Parfait !";
$LANG['install'][23]  = "Test d'écriture du fichier de configuration";
$LANG['install'][24]  = "Initialisation de la base de données.";
$LANG['install'][25]  = "Continuer ?";
$LANG['install'][26]  = "Continuer";
$LANG['install'][27]  = "Réessayer";
$LANG['install'][28]  = "Configuration de la connexion à la base de données";
$LANG['install'][29]  = "Paramètres de connexion à la base de données";
$LANG['install'][30]  = "Serveur MySQL";
$LANG['install'][31]  = "Utilisateur MySQL";
$LANG['install'][32]  = "Mot de passe MySQL";

$LANG['install'][34]  = "Test de connexion à la base de données";
$LANG['install'][35]  = "Impossible de se connecter à la base de données";
$LANG['install'][36]  = "Le serveur a répondu";
$LANG['install'][37]  = "Le champ serveur MySQL ou/et le champ utilisateur MySQL est vide";
$LANG['install'][38]  = "Veuillez sélectionner une base de données :";
$LANG['install'][39]  = "Créer une nouvelle base ou utiliser une base existante :";
$LANG['install'][40]  = "Veuillez sélectionner la base de données à mettre à jour :";
$LANG['install'][41]  = "Impossible d'utiliser la base :";

$LANG['install'][43]  = "OK - La base a bien été initialisée";

$LANG['install'][47]  = "Impossible d'écrire le fichier de configuration de votre base de données";
$LANG['install'][48]  = "Erreur lors de la création de la base !";
$LANG['install'][49]  = "Vous n'avez pas sélectionné de base de données !";
$LANG['install'][50]  = "Test d'écriture des fichiers de sessions";

$LANG['install'][52]  = "Test d'écriture des fichiers des actions automatiques";
$LANG['install'][53]  = "Test d'écriture des fichiers de log";

$LANG['install'][55]  = "L'installation est terminée";

$LANG['install'][57]  = "Les identifiants et mots de passe par défaut sont :";
$LANG['install'][58]  = "glpi/glpi pour le compte administrateur";
$LANG['install'][59]  = "tech/tech pour le compte technicien";
$LANG['install'][60]  = "normal/normal pour le compte normal";
$LANG['install'][61]  = "post-only/postonly pour le compte postonly";
$LANG['install'][62]  = "Vous pouvez supprimer ou modifier ces comptes ainsi que les données initiales.";

$LANG['install'][64]  = "Utiliser GLPI";
$LANG['install'][65]  = "Test sur l'extension magic_quotes_sybase";
$LANG['install'][66]  = "GLPI ne peut pas fonctionner avec l'option magic_quotes_sybase ; Veuillez désactiver cette option et réessayer";
$LANG['install'][67]  = "L'option magic_quotes_sybase n'est pas utilisée par votre serveur - Parfait !";
$LANG['install'][68]  = "Test sur le démarrage automatique des sessions";
$LANG['install'][69]  = "session.auto_start est activé. Reportez vous au fichier .htaccess à la racine de GLPI pour plus d'informations.";
$LANG['install'][70]  = "Impossible de créer le fichier de connexion à la base de données, vérifiez les droits sur les fichiers";
$LANG['install'][71]  = "Test de l'extension MySQL.";
$LANG['install'][72]  = "Vous devez compiler votre php avec l'extension MySQL.";
$LANG['install'][73]  = "Ok - la fonction mysql_query() existe - Parfait !";
$LANG['install'][74]  = "Test de l'utilisation de Session_use_trans_sid";
$LANG['install'][75]  = "Vous devez désactiver l'option Session_use_trans_id dans votre PHP.ini";
$LANG['install'][76]  = "Ok - Les sessions fonctionnent (pas de problèmes de trans_id) - Parfait !";
$LANG['install'][77]  = "Étape";

$LANG['install'][81]  = "Début de l'installation";
$LANG['install'][82]  = "Base de données créée";

$LANG['install'][85]  = "Les fonctions ont été trouvées - Parfait !";
$LANG['install'][86]  = "Test de la mémoire allouée";
$LANG['install'][87]  = "Mémoire allouée :";
$LANG['install'][88]  = "Un minimum de 64Mo est généralement nécessaire à GLPI.";
$LANG['install'][89]  = "Parfait !";
$LANG['install'][90]  = "Essayez d'augmenter le paramètre memory_limit dans le fichier php.ini.";
$LANG['install'][91]  = "Mémoire allouée > 64 Mo";
$LANG['install'][92]  = "Licence";
$LANG['install'][93]  = "J'ai lu et ACCEPTE les termes de la licence énoncés ci-dessus.";
$LANG['install'][94]  = "J'ai lu et N'ACCEPTE PAS les termes de la licence énoncés ci-dessus";
$LANG['install'][95]  = "Mémoire non limitée";
$LANG['install'][96]  = "Mémoire illimitée";
$LANG['install'][97]  = "Vérifiez les droits sur le répertoire :";

$LANG['install'][99]  = "Test d'écriture des fichiers de cache";
$LANG['install'][100] = "Le dossier n'a pas pu être créé.";
$LANG['install'][101] = "Le dossier a été créé mais n'a pas pu être supprimé.";
$LANG['install'][102] = "Test sur les fonctions Json";
$LANG['install'][103] = "GLPI ne peut pas fonctionner correctement sans les fonctions json_encode et json_decode";
$LANG['install'][104] = "Test sur l'extension mbstring";
$LANG['install'][105] = "L'extension mbstring de votre parseur PHP n'est pas installée";
$LANG['install'][106] = "Test d'écriture des fichiers de graphiques";


$LANG['job'][2]  = "par";
$LANG['job'][4]  = "Demandeur";
$LANG['job'][5]  = "Attribué à";
$LANG['job'][6]  = "Technicien";
$LANG['job'][7]  = "Tâche";
$LANG['job'][8]  = "dernier(s) ticket(s)";
$LANG['job'][9]  = "Suivi";

$LANG['job'][11] = "Description de la demande ou de l'incident";
$LANG['job'][12] = "Pas de suivi pour ce ticket.";
$LANG['job'][13] = "Nouveau ticket";

$LANG['job'][15] = "Résolus";

$LANG['job'][19] = "Suivi par courriel";
$LANG['job'][20] = "Durée totale";
$LANG['job'][21] = "Heure(s)";
$LANG['job'][22] = "Minute(s)";

$LANG['job'][29] = "Ajouter un nouveau suivi";
$LANG['job'][30] = "Ajouter une nouvelle tâche";
$LANG['job'][31] = "Durée";
$LANG['job'][32] = "Aucune";
$LANG['job'][33] = "Description vide";
$LANG['job'][34] = "Planifier cette tâche";
$LANG['job'][35] = "Planification";
$LANG['job'][37] = "Résumé";
$LANG['job'][38] = "Ticket";
$LANG['job'][39] = "Modifier un suivi";
$LANG['job'][40] = "Coût horaire";
$LANG['job'][41] = "Coût fixe";
$LANG['job'][42] = "Coût matériel";
$LANG['job'][43] = "Coût total";
$LANG['job'][44] = "Source de la demande";
$LANG['job'][45] = "Source du suivi";
$LANG['job'][46] = "Le ticket sera ajouté dans l'entité";
$LANG['job'][47] = "Coûts";
$LANG['job'][48] = "Type de solution";
$LANG['job'][49] = "Nouvelle tâche";
$LANG['job'][50] = "Pas de tâche pour ce ticket.";
$LANG['job'][51] = "Approbation de la solution";
$LANG['job'][52] = "Mise à jour d'une tâche";
$LANG['job'][53] = "Suppression d'une tâche";
$LANG['job'][54] = "Sans réponse de votre part, le ticket sera clos automatiquement après";


$LANG['joblist'][0]  = "Statut";
$LANG['joblist'][1]  = "Seulement les miens";
$LANG['joblist'][2]  = "Priorité";
$LANG['joblist'][3]  = "Personnel + groupe(s)";
$LANG['joblist'][4]  = "Attribué";

$LANG['joblist'][6]  = "Description";
$LANG['joblist'][7]  = "Nouveau ticket pour cet item...";
$LANG['joblist'][8]  = "Pas de ticket trouvé.";
$LANG['joblist'][9]  = "Nouveau";
$LANG['joblist'][10] = "Fermé (résolu)";
$LANG['joblist'][11] = "Ouvert le";
$LANG['joblist'][12] = "Clos le";
$LANG['joblist'][13] = "Tickets à traiter";
$LANG['joblist'][14] = "Résolu le";

$LANG['joblist'][16] = "Pas de ticket en cours.";
$LANG['joblist'][17] = "Fermé (non résolu)";
$LANG['joblist'][18] = "En cours (Attribué)";
$LANG['joblist'][19] = "En cours (Planifié)";

$LANG['joblist'][21] = "En cours";

$LANG['joblist'][26] = "En attente";
$LANG['joblist'][27] = "Courriel pour le suivi";
$LANG['joblist'][28] = "Tickets sur les éléments liés";
$LANG['joblist'][29] = "Urgence";
$LANG['joblist'][30] = "Impact";
$LANG['joblist'][32] = "Résolu";
$LANG['joblist'][33] = "Clos";
$LANG['joblist'][34] = "Non résolu";
$LANG['joblist'][35] = "Non clos";
$LANG['joblist'][36] = "Valeur du statut en base";


$LANG['jobresolution'][1] = "Solution";

$LANG['jobresolution'][3] = "Solution approuvée";
$LANG['jobresolution'][4] = "Solution rejetée";
$LANG['jobresolution'][5] = "En cas de rejet de la solution, vous devez indiquer un motif";


$LANG['knowbase'][1]  = "Foire aux questions";

$LANG['knowbase'][5]  = "Placer cet item dans la FAQ";
$LANG['knowbase'][6]  = "Sélectionner une catégorie pour cet item :";
$LANG['knowbase'][7]  = "Retirer cet item de la FAQ";
$LANG['knowbase'][8]  = "Modifier cet item";
$LANG['knowbase'][9]  = "Supprimer cet item";
$LANG['knowbase'][10] = "Cet item fait partie de la FAQ";
$LANG['knowbase'][11] = "Cet item ne fait pas partie de la FAQ";
$LANG['knowbase'][12] = "Racine";
$LANG['knowbase'][13] = "Nom de la catégorie";
$LANG['knowbase'][14] = "Sujet";
$LANG['knowbase'][15] = "Contenu";

$LANG['knowbase'][24] = "Accéder à la Foire Aux Questions";

$LANG['knowbase'][26] = "Vues";
$LANG['knowbase'][27] = "Le";

$LANG['knowbase'][29] = "Sujets les plus récents";
$LANG['knowbase'][30] = "Sujets les plus populaires";


$LANG['ldap'][0]  = "Import en masse d'utilisateurs depuis un annuaire LDAP";
$LANG['ldap'][1]  = "Synchronisation des utilisateurs déjà importés";
$LANG['ldap'][2]  = "Importation de nouveaux utilisateurs";
$LANG['ldap'][3]  = "Pas d'utilisateurs à importer";
$LANG['ldap'][4]  = "Choix de l'annuaire LDAP";
$LANG['ldap'][5]  = "Veuillez choisir l'annuaire LDAP depuis lequel les utilisateurs seront importés";
$LANG['ldap'][6]  = "Impossible de joindre l'annuaire LDAP";
$LANG['ldap'][7]  = "Aucun annuaire LDAP défini dans GLPI";
$LANG['ldap'][8]  = "Attention : la requête dépasse la limite de l'annuaire. Les résultats ne sont que partiels.";
$LANG['ldap'][9]  = "Test de connexion à l'annuaire LDAP";

$LANG['ldap'][12] = "Synchronisation";
$LANG['ldap'][13] = "dans l'annuaire LDAP";
$LANG['ldap'][14] = "dans GLPI";
$LANG['ldap'][15] = "Synchroniser";
$LANG['ldap'][16] = "Préconfiguration";
$LANG['ldap'][17] = "Active Directory";
$LANG['ldap'][18] = "Liste des réplicats d'annuaires LDAP";
$LANG['ldap'][19] = "Réplicat";
$LANG['ldap'][20] = "Ajout d'un réplicat d'annuaire LDAP";
$LANG['ldap'][21] = "Serveur principal";
$LANG['ldap'][22] = "Réplicat(s)";
$LANG['ldap'][23] = "Import en masse de groupes depuis un annuaire LDAP";
$LANG['ldap'][24] = "Importation de nouveaux groupes";
$LANG['ldap'][25] = "Pas de groupes à importer";

$LANG['ldap'][30] = "Traitement des alias LDAP";
$LANG['ldap'][31] = "Jamais déréférencés (défaut)";
$LANG['ldap'][32] = "Toujours déréférencés";
$LANG['ldap'][33] = "Déréférencés pendant la recherche";
$LANG['ldap'][34] = "Déréférencés pendant la localisation";
$LANG['ldap'][35] = "Importer un utilisateur";
$LANG['ldap'][36] = "Aucun annuaire associé à l'entité : recherche impossible";

$LANG['ldap'][38] = "Critères de recherche des utilisateurs";
$LANG['ldap'][39] = "Avancée";
$LANG['ldap'][40] = "Simple";
$LANG['ldap'][41] = "Changer";
$LANG['ldap'][42] = "Aucun annuaire sélectionné";
$LANG['ldap'][43] = "Pas d'utilisateurs à synchroniser";
$LANG['ldap'][44] = "Serveur par défaut";
$LANG['ldap'][45] = "Action lorsqu'un utilisateur est supprimé de l'annuaire LDAP";
$LANG['ldap'][46] = "Retirer les habilitations et les groupes (dynamiques)";
$LANG['ldap'][47] = "Mettre à la corbeille";
$LANG['ldap'][48] = "Utilisateur supprimé de l'annuaire LDAP";
$LANG['ldap'][49] = "Voir les utilisateurs ajoutés depuis";
$LANG['ldap'][50] = "Voir les utilisateurs modifiés depuis";
$LANG['ldap'][52] = "Moins de";
$LANG['ldap'][53] = "Plus de";
$LANG['ldap'][54] = "Activer le filtrage par date";
$LANG['ldap'][55] = "Désactiver le filtrage par date";
$LANG['ldap'][56] = "Semaines";

$LANG['links'][1] = "Lien ou nom du fichier";

$LANG['links'][4] = "Types de matériel associés";
$LANG['links'][6] = "Balises valides";
$LANG['links'][7] = "Aucun lien défini";
$LANG['links'][9] = "Contenu du fichier";


$LANG['log'][1]   = "système";
$LANG['log'][16]  = "planning";
$LANG['log'][18]  = "composants";
$LANG['log'][20]  = "ajout de l'item";
$LANG['log'][21]  = "mise à jour de l'item";
$LANG['log'][22]  = "suppression de l'item";
$LANG['log'][23]  = "restauration de l'item";
$LANG['log'][24]  = "purge de l'item";

$LANG['log'][26]  = "déconnexion de l'item";
$LANG['log'][27]  = "connexion de l'item";
$LANG['log'][28]  = "modification des composants";
$LANG['log'][29]  = "approbation/rejet de la solution";
$LANG['log'][30]  = "association d'un type";
$LANG['log'][31]  = "suppression d'un type";
$LANG['log'][32]  = "ajout lien avec un item";
$LANG['log'][33]  = "suppression lien avec un item";
$LANG['log'][34]  = "ajout lien avec fournisseur";
$LANG['log'][35]  = "suppression lien avec fournisseur";

$LANG['log'][40]  = "connexion de l'IP";
$LANG['log'][41]  = "échec de connexion";
$LANG['log'][42]  = "Réservation";
$LANG['log'][44]  = "Intitulé";
$LANG['log'][45]  = "Réussie";
$LANG['log'][46]  = "Échouée";
$LANG['log'][48]  = "ajout utilisateur au groupe";
$LANG['log'][49]  = "suppression utilisateur au groupe";

$LANG['log'][55]  = "Connexion";

$LANG['log'][59]  = "Action automatique";
$LANG['log'][60]  = "passage en gestion unitaire de l'item";
$LANG['log'][61]  = "ajout utilisateur à l'entité";
$LANG['log'][62]  = "suppression utilisateur à l'entité";
$LANG['log'][64]  = "modification du champ";
$LANG['log'][65]  = "règle";
$LANG['log'][66]  = "Sécurité";
$LANG['log'][67]  = "modification des notes";

$LANG['log'][70]  = "ajout d'un port réseau";
$LANG['log'][71]  = "ajout de plusieurs ports réseau";

$LANG['log'][73]  = "suppression d'un port réseau";
$LANG['log'][74]  = "suppression de plusieurs ports réseau";
$LANG['log'][75]  = "déplacement d'un port réseau";

$LANG['log'][77]  = "association d'un VLAN à un port réseau";
$LANG['log'][78]  = "association d'un VLAN à plusieurs ports réseau";
$LANG['log'][79]  = "dissociation d'un VLAN à un port réseau";
$LANG['log'][80]  = "dissociation d'un VLAN à plusieurs ports réseau";
$LANG['log'][82]  = "ajout de la version";
$LANG['log'][83]  = "modification de la version";
$LANG['log'][84]  = "suppression de la version";
$LANG['log'][85]  = "ajout de la licence";
$LANG['log'][86]  = "modification de la licence";
$LANG['log'][87]  = "suppression de la licence";
$LANG['log'][88]  = "ajout de cartouches";
$LANG['log'][89]  = "ajout de consommables";
$LANG['log'][90]  = "suppression d'une cartouche";
$LANG['log'][91]  = "suppression d'un consommable";
$LANG['log'][92]  = "restauration une cartouche";
$LANG['log'][93]  = "restauration d'un consommable";
$LANG['log'][94]  = "mise à jour d'une cartouche";
$LANG['log'][95]  = "installation d'une cartouche";
$LANG['log'][96]  = "désinstallation d'une cartouche";
$LANG['log'][97]  = "sortie d'un consommable pour l'utilisateur";
$LANG['log'][98]  = "ajout d'un élément";
$LANG['log'][99]  = "modification d'un élément";
$LANG['log'][100] = "suppression d'un élément";


$LANG['login'][0]  = "Dernière connexion";
$LANG['login'][1]  = "Se reconnecter";
$LANG['login'][2]  = "Annuaire LDAP";
$LANG['login'][3]  = "IMAP/POP";
$LANG['login'][4]  = "CAS";
$LANG['login'][5]  = "Accès refusé";
$LANG['login'][6]  = "Identifiant";
$LANG['login'][7]  = "Mot de passe";
$LANG['login'][8]  = "Identifiant ou mot de passe vide";
$LANG['login'][9]  = "Pas encore authentifié";
$LANG['login'][10] = "Authentification";
$LANG['login'][11] = "Utilisateur non autorisé à se connecter";
$LANG['login'][12] = "Identifiant ou mot de passe erroné";
$LANG['login'][13] = "Mot de passe vide";
$LANG['login'][14] = "Utilisateur inconnu";
$LANG['login'][15] = "Utilisateur non trouvé ou plusieurs utilisateurs identiques trouvés";
$LANG['login'][16] = "Échec de l'authentification LDAP";

$LANG['login'][18] = "Base interne GLPI";

$LANG['login'][20] = "Vous n'avez pas accès à cette application car votre compte a été désactivé ou supprimé";
$LANG['login'][21] = "Test de connexion au serveur IMAP/POP";
$LANG['login'][22] = "Test réussi";
$LANG['login'][23] = "Test échoué";
$LANG['login'][24] = "Date dernière mise à jour";
$LANG['login'][25] = "Vous n'avez aucun droit pour vous connecter à cette application";
$LANG['login'][26] = "Vous devez activer la fonction JavaScript de votre navigateur";
$LANG['login'][27] = "Vous devez autoriser les cookies pour accéder à cette application";

$LANG['login'][30] = "Changement de la méthode d'authentification";
$LANG['login'][31] = "Authentification sur un annuaire LDAP";
$LANG['login'][32] = "Authentification sur la base GLPI";
$LANG['login'][33] = "Authentification sur le serveur POP/IMAP";


$LANG['mailgate'][0]  = "Collecteur Mail";

$LANG['mailgate'][2]  = "Récupérer maintenant";
$LANG['mailgate'][3]  = "Nombre de messages disponibles et récupérés";
$LANG['mailgate'][4]  = "Extension mbstring indisponible. Attention aux jeux de caractères utilisés.";
$LANG['mailgate'][5]  = "Fichier attaché invalide";
$LANG['mailgate'][6]  = "Fichier attaché trop volumineux";
$LANG['mailgate'][7]  = "Taille maximale des fichiers importés par le collecteur";
$LANG['mailgate'][9]  = "Votre email n'a pu être traité.\nVeuillez contacter l'administrateur si le problème persiste";
$LANG['mailgate'][10] = "Email rejeté";
$LANG['mailgate'][11] = "Processus d'import d'emails";
$LANG['mailgate'][12] = "Impossible d'affecter l'email à une entité";
$LANG['mailgate'][13] = "Raison du refus";
$LANG['mailgate'][14] = "Email absent. Import impossible";
$LANG['mailgate'][16] = "Re:";

$LANG['mailing'][0]   = "----------------------------------------------------------";
$LANG['mailing'][1]   = "======================================================================";

$LANG['mailing'][4]   = "Suivi(s) déjà effectué(s)";
$LANG['mailing'][5]   = "Description du ticket";

$LANG['mailing'][10]  = "Nouveau suivi pour ce ticket";

$LANG['mailing'][12]  = "Attribution du ticket";

$LANG['mailing'][14]  = "Changement de catégorie du ticket";
$LANG['mailing'][15]  = "Changement de priorité du ticket";

$LANG['mailing'][17]  = "Changement de matériel concerné par le ticket";
$LANG['mailing'][18]  = "Changement du demandeur du ticket";
$LANG['mailing'][19]  = "Nouvelle réservation";
$LANG['mailing'][20]  = "Changement de groupe demandeur du ticket";

$LANG['mailing'][21]  = "Changement de la source du ticket";
$LANG['mailing'][23]  = "Modification réservation";

$LANG['mailing'][26]  = "Document ajouté :";
$LANG['mailing'][27]  = "Changement de statut du ticket";

$LANG['mailing'][29]  = "Annulation réservation";
$LANG['mailing'][30]  = "Modification Ticket";
$LANG['mailing'][31]  = "Ceci est le mail de test d'envoi de mail";
$LANG['mailing'][32]  = "Mail Test";
$LANG['mailing'][33]  = "Alerte Cartouches";

$LANG['mailing'][35]  = "Seuil d'alerte atteint pour le type de consommable :";
$LANG['mailing'][36]  = "Alerte consommables";
$LANG['mailing'][37]  = "Contrat entré dans la période de préavis :";
$LANG['mailing'][39]  = "Alerte Contrats";
$LANG['mailing'][40]  = "Matériel arrivé en fin de garantie :";
$LANG['mailing'][41]  = "Alerte Informations Financières";
$LANG['mailing'][42]  = "Changement du coût horaire";
$LANG['mailing'][43]  = "Changement du coût fixe";
$LANG['mailing'][44]  = "Changement du coût matériel";
$LANG['mailing'][45]  = "Changement du titre du ticket";
$LANG['mailing'][46]  = "Changement de la description du ticket";
$LANG['mailing'][47]  = "Erreur dans l'envoi de l'email";
$LANG['mailing'][48]  = "Changement de la date d'ouverture";
$LANG['mailing'][49]  = "Changement de la date de clôture";
$LANG['mailing'][50]  = "Changement du receveur du ticket";
$LANG['mailing'][51]  = "Licence expirée :";

$LANG['mailing'][53]  = "Changement de solution";
$LANG['mailing'][54]  = "Date d'expiration";

$LANG['mailing'][100] = "Pas de catégorie attribuée";
$LANG['mailing'][101] = "Le suivi par email a été activé";
$LANG['mailing'][102] = "Le suivi par email a été désactivé";

$LANG['mailing'][104] = "Durée de l'intervention";
$LANG['mailing'][105] = "Non attribué";

$LANG['mailing'][107] = "Pas de matériel concerné";

$LANG['mailing'][109] = "Pas de groupe";
$LANG['mailing'][110] = "Email invalide";

$LANG['mailing'][113] = "Modèles de notifications";
$LANG['mailing'][114] = "Corps";
$LANG['mailing'][115] = "Corps de l'email";
$LANG['mailing'][116] = "HTML";
$LANG['mailing'][117] = "texte";
$LANG['mailing'][118] = "Email";
$LANG['mailing'][119] = "Événement";
$LANG['mailing'][120] = "Mode de notification";
$LANG['mailing'][121] = "Destinataires";
$LANG['mailing'][122] = "Tâche(s) déjà effectuée(s)";
$LANG['mailing'][123] = "Ticket résolu";
$LANG['mailing'][124] = "Ajouter une nouvelle traduction";
$LANG['mailing'][125] = "Traduction par défaut";
$LANG['mailing'][126] = "Traduction d'un modèle";
$LANG['mailing'][127] = "Clôture du ticket";
$LANG['mailing'][128] = "laisser le champs vide pour une génération à partir du HTML";
$LANG['mailing'][129] = "Suppression d'un ticket";
$LANG['mailing'][130] = "Expéditeur";
$LANG['mailing'][131] = "Destinataire";
$LANG['mailing'][132] = "En-tête de l'email";
$LANG['mailing'][133] = "Supprimer email(s)";
$LANG['mailing'][134] = "Mise à jour suivi";
$LANG['mailing'][135] = "Suppression suivi";
$LANG['mailing'][136] = "Expiration réservation";
$LANG['mailing'][137] = "Utilisateur du matériel";
$LANG['mailing'][138] = "Liste des balises disponibles";
$LANG['mailing'][139] = "Libellé";
$LANG['mailing'][140] = "Balise";
$LANG['mailing'][141] = "Suivis";
$LANG['mailing'][142] = "Tâches";
$LANG['mailing'][143] = "Validations";
$LANG['mailing'][144] = "Historique";
$LANG['mailing'][145] = "Liste de valeurs";
$LANG['mailing'][146] = "Valeur unique";
$LANG['mailing'][147] = "Valeur(s) possible(s)";


$LANG['Menu'][0]  = "Ordinateurs";
$LANG['Menu'][1]  = "Réseaux";
$LANG['Menu'][2]  = "Imprimantes";
$LANG['Menu'][3]  = "Moniteurs";
$LANG['Menu'][4]  = "Logiciels";
$LANG['Menu'][5]  = "Tickets";
$LANG['Menu'][6]  = "Rapports";

$LANG['Menu'][11] = "Préférences";
$LANG['Menu'][12] = "Maintenance";
$LANG['Menu'][13] = "Statistiques";
$LANG['Menu'][14] = "Utilisateurs";
$LANG['Menu'][15] = "Administration";
$LANG['Menu'][16] = "Périphériques";
$LANG['Menu'][17] = "Réservations";
$LANG['Menu'][18] = "Outils";
$LANG['Menu'][19] = "Base de connaissances";
$LANG['Menu'][20] = "FAQ";
$LANG['Menu'][21] = "Cartouches";
$LANG['Menu'][22] = "Contacts";
$LANG['Menu'][23] = "Fournisseurs";
$LANG['Menu'][24] = "Infos financières";
$LANG['Menu'][25] = "Contrats";
$LANG['Menu'][26] = "Gestion";
$LANG['Menu'][27] = "Documents";
$LANG['Menu'][28] = "Statuts";
$LANG['Menu'][29] = "Planning";
$LANG['Menu'][30] = "Journaux";
$LANG['Menu'][31] = "Interface simplifiée";
$LANG['Menu'][32] = "Consommables";
$LANG['Menu'][33] = "OCSNG";
$LANG['Menu'][34] = "Téléphones";
$LANG['Menu'][35] = "Profils";
$LANG['Menu'][36] = "Groupes";
$LANG['Menu'][37] = "Entités";
$LANG['Menu'][38] = "Inventaire";
$LANG['Menu'][39] = "Collecteurs";
$LANG['Menu'][40] = "Marque-pages";
$LANG['Menu'][41] = "Droits";

$LANG['monitors'][14]="Microphone";
$LANG['monitors'][15]="Enceintes";
$LANG['monitors'][18]="Options";
$LANG['monitors'][19]="Sub-D";
$LANG['monitors'][20]="BNC";
$LANG['monitors'][21]="Taille";
$LANG['monitors'][32]="DVI";
$LANG['monitors'][33]="Pivot";

$LANG['networking'][4]="Port réseau";
$LANG['networking'][5]="Mémoire (Mio)";
$LANG['networking'][6]="Ports réseaux";
$LANG['networking'][13]="port(s) réseau trouvé(s)";
$LANG['networking'][14]="IP";
$LANG['networking'][15]="MAC";
$LANG['networking'][17]="Connecté à";
$LANG['networking'][19]="Ajouter un port...";
$LANG['networking'][21]="Numéro de port";
$LANG['networking'][25]="sur";
$LANG['networking'][37]="port(s) réseau trouvé(s)";
$LANG['networking'][44]="Le port";
$LANG['networking'][46]="Ajouter plusieurs ports...";
$LANG['networking'][47]="De";
$LANG['networking'][48]="A";
$LANG['networking'][51]="Prise réseau";
$LANG['networking'][55]="Associer un VLAN";
$LANG['networking'][56]="VLAN";
$LANG['networking'][57]="Choisissez une adresse MAC dans la liste ou spécifiez-la ci-dessous.";
$LANG['networking'][58]="Dissocier un VLAN";
$LANG['networking'][59]="Passerelle";
$LANG['networking'][60]="Masque";
$LANG['networking'][61]="Sous-réseau";

$LANG['ocsconfig'][1]="Utilisateur de la base de données OCSNG";
$LANG['ocsconfig'][2]="Hôte de la base de données OCSNG";
$LANG['ocsconfig'][3]="Mot de passe de l'utilisateur OCSNG";
$LANG['ocsconfig'][4]="Nom de la base de données OCSNG";
$LANG['ocsconfig'][5]="Options d'importation";
$LANG['ocsconfig'][6]="Ignorer lors de l'import OCSNG";
$LANG['ocsconfig'][7]="Base de données OCSNG en UTF8";
$LANG['ocsconfig'][9]="Exclure les tags suivants (séparateur $, rien pour aucun)";
$LANG['ocsconfig'][10]="Import global";
$LANG['ocsconfig'][11]="Pas d'import";
$LANG['ocsconfig'][12]="Import unique";
$LANG['ocsconfig'][13]="Import unique : tout est importé tel quel";
$LANG['ocsconfig'][14]="Import global : tout est importé mais le matériel est géré de manière globale (sans doublons)";
$LANG['ocsconfig'][15]="Pas d'import : GLPI n'importera pas ces éléments";
$LANG['ocsconfig'][16]="Statut par défaut";
$LANG['ocsconfig'][17]="Limiter l'importation aux tags suivants (séparateur $, rien pour tous)";
$LANG['ocsconfig'][18]="Assurez vous au préalable d'avoir géré correctement les doublons dans OCSNG";
$LANG['ocsconfig'][19]="Import unique sur numéro de série";
$LANG['ocsconfig'][27]="Informations générales";
$LANG['ocsconfig'][36]="Modems";
$LANG['ocsconfig'][37]="Ports";
$LANG['ocsconfig'][38]="Utiliser le dictionnaire logiciel d'OCSNG";
$LANG['ocsconfig'][39]="TAG OCSNG";
$LANG['ocsconfig'][40]="Nombre d'éléments à synchroniser via l'action automatique ocsng";
$LANG['ocsconfig'][41]="Base de registre";
$LANG['ocsconfig'][43]="Informations Administratives OCSNG";
$LANG['ocsconfig'][48]="Comportement lors de la déconnexion";
$LANG['ocsconfig'][49]="Corbeille";
$LANG['ocsconfig'][50]="Suppression";
$LANG['ocsconfig'][52]="Liaison automatique des ordinateurs";
$LANG['ocsconfig'][53]="Activer la liaison automatique";
$LANG['ocsconfig'][54]="Critères d'existence d'un ordinateur";
$LANG['ocsconfig'][55]="Chercher les ordinateurs GLPI ayant le statut";
$LANG['ocsconfig'][56]="vide";
$LANG['ocsconfig'][57]="égal";
$LANG['ocsconfig'][58]="La liaison fusionne automatiquement un ordinateur GLPI avec un d'OCSNG.<br>Cette option est prise en compte lors de la liaison manuelle et par les scripts de synchronisation.";
$LANG['ocsconfig'][59]="Chemin d'accès web de la console OCSNG";

$LANG['ocsng'][0]="OCS Inventory NG";
$LANG['ocsng'][1]="Synchronisation des ordinateurs déjà importés";
$LANG['ocsng'][2]="Importation de nouveaux ordinateurs";
$LANG['ocsng'][3]="Nettoyage des liens GLPI / OCSNG";
$LANG['ocsng'][4]="Lier de nouveaux ordinateurs à des ordinateurs existants";
$LANG['ocsng'][5]="Importer nouveaux ordinateurs";
$LANG['ocsng'][6]="Mise à jour automatique";
$LANG['ocsng'][7]="Importé depuis OCSNG";
$LANG['ocsng'][8]="Importation réussie";
$LANG['ocsng'][9]="Pas de nouvel ordinateur à importer";
$LANG['ocsng'][10]="Ordinateurs mis à jour dans OCSNG";
$LANG['ocsng'][11]="Mise à jour des ordinateurs";
$LANG['ocsng'][12]="Pas de nouvel ordinateur à mettre à jour";
$LANG['ocsng'][13]="Date d'import dans GLPI";
$LANG['ocsng'][14]="Date dernier inventaire OCSNG";
$LANG['ocsng'][15]="Aucun champ verrouillé";
$LANG['ocsng'][16]="Champs verrouillés";
$LANG['ocsng'][18]="Connexion à la base de données OCSNG réussie";
$LANG['ocsng'][19]="Version et Configuration OCSNG valide";
$LANG['ocsng'][20]="Version d'OCSNG non valide : nécessite RC3";
$LANG['ocsng'][21]="Échec de connexion à la base de données OCSNG";
$LANG['ocsng'][22]="Attention ! Les données importées (voir votre configuration) écraseront les données existantes";
$LANG['ocsng'][23]="Importation impossible, ordinateur de destination de GLPI déjà lié à un élément d'OCSNG";
$LANG['ocsng'][24]="Forcer la synchronisation";
$LANG['ocsng'][26]="Choix d'un serveur OCSNG";
$LANG['ocsng'][27]="Aucun serveur OCSNG n'est défini";
$LANG['ocsng'][29]="Serveur OCSNG";
$LANG['ocsng'][30]="Moniteur(s) verrouillé(s)";
$LANG['ocsng'][32]="Périphérique(s) verrouillé(s)";
$LANG['ocsng'][34]="Imprimante(s) verrouillée(s)";
$LANG['ocsng'][36]="Entité de destination";
$LANG['ocsng'][37]="Activer la prévisualisation";
$LANG['ocsng'][38]="Désactiver la prévisualisation";
$LANG['ocsng'][40]="Vérifie la règle ?";
$LANG['ocsng'][41]="Mode d'import manuel";
$LANG['ocsng'][42]="Configuration OCSNG invalide (TRACE_DELETED doit être activé)";
$LANG['ocsng'][43]="Accès refusé sur la base OCSNG (Droit d'écriture sur hardware.CHECKSUM nécessaire)";
$LANG['ocsng'][44]="Accès refusé sur la base OCSNG (Droit de suppression sur deleted_equiv nécessaire)";
$LANG['ocsng'][45]="ID OCS";
$LANG['ocsng'][46]="Supprimé d'OCSNG";
$LANG['ocsng'][47]="Lié avec un ordinateur d'OCSNG";
$LANG['ocsng'][48]="L'ordinateur a changé d'ID OCSNG";
$LANG['ocsng'][49]="Agent";
$LANG['ocsng'][50]="IP(s) verrouillée(s)";
$LANG['ocsng'][52]="Logiciel(s) verrouillé(s)";
$LANG['ocsng'][54]="Logiciel mis dans la corbeille par la synchro OCSNG";
$LANG['ocsng'][55]="Volume(s) verrouillé(s)";
$LANG['ocsng'][56]="Composant(s) verrouillé(s)";
$LANG['ocsng'][57]="Interface OCSNG";

$LANG['pager'][1]="à";
$LANG['pager'][2]="de";
$LANG['pager'][3]="sur";
$LANG['pager'][4]="Afficher";
$LANG['pager'][5]="éléments";

$LANG['peripherals'][18]="Marque";
$LANG['peripherals'][31]="Gestion globale";
$LANG['peripherals'][32]="Gestion unitaire";
$LANG['peripherals'][33]="Type de gestion";

$LANG['phones'][18]="Marque";
$LANG['phones'][36]="Alimentation";
$LANG['phones'][38]="Casque";
$LANG['phones'][39]="Haut parleur";
$LANG['phones'][40]="Nombre de lignes";

$LANG['planning'][0]="Le technicien demandé a déjà une intervention prévue pour cette plage.";
$LANG['planning'][1]="Erreur dans l'entrée de vos dates. La date de début est sûrement supérieure à la date de fin";
$LANG['planning'][5]="Journée";
$LANG['planning'][6]="Semaine";
$LANG['planning'][8]="Intervention";
$LANG['planning'][9]="Par";
$LANG['planning'][10]="Ical";
$LANG['planning'][11]="Webcal";
$LANG['planning'][12]="Télécharger planning format Ical";
$LANG['planning'][13]="Synchronisation Webcal://";
$LANG['planning'][14]="Mois";
$LANG['planning'][15]="Votre planning";
$LANG['planning'][16]="Information";
$LANG['planning'][17]="A faire";
$LANG['planning'][18]="Fait";

$LANG['plugins'][0]="Liste des plugins";
$LANG['plugins'][2]="Installé / non configuré";
$LANG['plugins'][3]="Installé / non activé";
$LANG['plugins'][4]="Erreur / à nettoyer";
$LANG['plugins'][5]="Fonction(s) inexistante(s)";
$LANG['plugins'][6]="A mettre à jour";
$LANG['plugins'][7]="Aucun plugin installé";
$LANG['plugins'][8]="Voir le catalogue des plugins";
$LANG['plugins'][9]="Auteurs";
$LANG['plugins'][10]="Plugin incompatible avec cette version de GLPI";

$LANG['printers'][14]="Série";
$LANG['printers'][15]="Parallèle";
$LANG['printers'][18]="Ports";
$LANG['printers'][27]="USB";
$LANG['printers'][28]="Ethernet";
$LANG['printers'][29]="Wifi";
$LANG['printers'][30]="Compteur de page initial";
$LANG['printers'][31]="Pages imprimées";

$LANG['profiles'][0]="Droit global";
$LANG['profiles'][1]="Droit local";
$LANG['profiles'][2]="Interface associée au profil";
$LANG['profiles'][4]="Ajouter un suivi aux tickets des groupes associés";
$LANG['profiles'][5]="Créer un ticket";
$LANG['profiles'][6]="Ajouter un suivi aux tickets (demandeur)";
$LANG['profiles'][7]="Voir tous les tickets";
$LANG['profiles'][8]="Voir tous les suivis et tâches (publics et privés)";
$LANG['profiles'][9]="Voir les suivis et tâches publics";
$LANG['profiles'][10]="Lecture";
$LANG['profiles'][11]="Écriture";
$LANG['profiles'][12]="Aucun Accès";
$LANG['profiles'][13]="Profil par défaut";
$LANG['profiles'][14]="Supprimer un ticket";
$LANG['profiles'][15]="Ajouter un suivi à tous les tickets";
$LANG['profiles'][16]="Être en charge d'un ticket";
$LANG['profiles'][17]="Voler un ticket";
$LANG['profiles'][18]="Éditer un ticket";
$LANG['profiles'][19]="Attribuer un ticket";
$LANG['profiles'][20]="Voir planning personnel";
$LANG['profiles'][21]="Voir tous les plannings";
$LANG['profiles'][22]="Profil";
$LANG['profiles'][23]="Administration des réservations";
$LANG['profiles'][24]="Mise à jour de mot de passe";
$LANG['profiles'][26]="Voir les tickets créés par groupe(s) associé(s)";
$LANG['profiles'][27]="Voir les matériels du ou des groupe(s) associé(s)";
$LANG['profiles'][28]="Récursif";
$LANG['profiles'][29]="Dynamique";
$LANG['profiles'][30]="Voir les informations OCSNG";
$LANG['profiles'][31]="Synchronisation OCSNG manuellement";
$LANG['profiles'][32]="Voir les tickets attribués (personnel + groupe(s) associé(s)";
$LANG['profiles'][33]="Pas d'utilisateur trouvé";
$LANG['profiles'][34]="Légende";
$LANG['profiles'][35]="Éditer tous les suivis";
$LANG['profiles'][36]="Voir les planning de personnes de mes groupes";
$LANG['profiles'][37]="Entité par défaut";
$LANG['profiles'][38]="Vision";
$LANG['profiles'][39]="Attribution";
$LANG['profiles'][40]="Édition";
$LANG['profiles'][41]="Création";
$LANG['profiles'][42]="Association";
$LANG['profiles'][43]="Méthode d'authentification et synchronisation des utilisateurs";
$LANG['profiles'][44]="Modifier la priorité";
$LANG['profiles'][45]="Ajouter une tâche à tous les tickets";
$LANG['profiles'][46]="Éditer toutes les tâches";
$LANG['profiles'][47]="Ajout d'utilisateur depuis une source externe";
$LANG['profiles'][48]="Faire une demande de validation de ticket";
$LANG['profiles'][49]="Valider un ticket";

$LANG['registry'][1]="Ruche";
$LANG['registry'][2]="Chemin";
$LANG['registry'][3]="Clé/valeur";
$LANG['registry'][4]="Clé(s) de registre trouvée(s)";
$LANG['registry'][5]="Aucune clé de la base de registre trouvée";
$LANG['registry'][6]="Nom OCSNG";

$LANG['reminder'][0]="Notes personnelles";
$LANG['reminder'][1]="Notes publiques";
$LANG['reminder'][6]="Nouvelle note";
$LANG['reminder'][9]="Texte";
$LANG['reminder'][12]="Ajouter au planning";
$LANG['reminder'][15]="Sans titre";
$LANG['reminder'][16]="Notes globales";


$LANG['reports'][0]="Sélectionner un rapport à générer";
$LANG['reports'][4]="Liste du matériel sous contrat";
$LANG['reports'][11]="Matériel sous contrat";
$LANG['reports'][12]="Type(s) de matériel";
$LANG['reports'][13]="Date(s)";
$LANG['reports'][15]="Afficher rapport";
$LANG['reports'][19]="Nom usager";
$LANG['reports'][26]="Rapport par défaut";
$LANG['reports'][27]="Par contrat";
$LANG['reports'][28]="Par année";
$LANG['reports'][33]="Rapport réseau";
$LANG['reports'][36]="Périphériques connectés";
$LANG['reports'][37]="Prises";
$LANG['reports'][38]="IP";
$LANG['reports'][39]="Par lieu";
$LANG['reports'][41]="Par équipement";
$LANG['reports'][42]="Par prise";
$LANG['reports'][46]="port de l'équipement";
$LANG['reports'][47]="port du périphérique";
$LANG['reports'][49]="Rapport réseau par équipement";
$LANG['reports'][51]="Rapport réseau par prise";
$LANG['reports'][52]="switch";
$LANG['reports'][54]="Rapport réseau pour le lieu";
$LANG['reports'][57]="Liste des matériels";
$LANG['reports'][58]="Rapport des matériels par année";
$LANG['reports'][60]="Date d'ouverture";
$LANG['reports'][61]="Date de clôture";
$LANG['reports'][62]="Informations financières inventaire matériel";
$LANG['reports'][63]="Informations financières autres (licences, consommables, cartouches)";
$LANG['reports'][64]="Date de résolution";

$LANG['reservation'][1]="Matériel réservable";
$LANG['reservation'][2]="Matériel temporairement indisponible";
$LANG['reservation'][3]="Rendre indisponible";
$LANG['reservation'][5]="Rendre disponible";
$LANG['reservation'][6]="Interdire les réservations";
$LANG['reservation'][7]="Autoriser les réservations";
$LANG['reservation'][8]="Réserver";
$LANG['reservation'][9]="Réserver un matériel";
$LANG['reservation'][16]="Jusqu'à";
$LANG['reservation'][17]="Dès";
$LANG['reservation'][18]="Le matériel demandé est déjà réservé pour cette plage.";
$LANG['reservation'][20]="Retour au planning";
$LANG['reservation'][21]="Voir le planning";
$LANG['reservation'][22]="Modifier le commentaire";
$LANG['reservation'][25]="Tous les matériels réservables";
$LANG['reservation'][27]="Répétition";
$LANG['reservation'][28]="Par semaine";
$LANG['reservation'][29]="Par jour";
$LANG['reservation'][30]="fois";
$LANG['reservation'][31]="Par";
$LANG['reservation'][35]="Réservations en cours et à venir";
$LANG['reservation'][36]="Réservations passées";
$LANG['reservation'][37]="Pas de réservations";
$LANG['reservation'][38]="Êtes-vous sur de vouloir rendre cet élément non réservable ?";
$LANG['reservation'][39]="Cela supprimera toutes les réservations en cours.";
$LANG['reservation'][40]="Matériels dont la réservation expire aujourd'hui";

$LANG['rulesengine'][0]="est";
$LANG['rulesengine'][1]="n'est pas";
$LANG['rulesengine'][2]="contient";
$LANG['rulesengine'][3]="ne contient pas";
$LANG['rulesengine'][4]="commence par";
$LANG['rulesengine'][5]="finit par";
$LANG['rulesengine'][6]="Critères";
$LANG['rulesengine'][7]="Actions";
$LANG['rulesengine'][8]="Gestion de règles";
$LANG['rulesengine'][9]="Opérateur logique";
$LANG['rulesengine'][10]="Classement";

$LANG['rulesengine'][11]="Type d'action";
$LANG['rulesengine'][12]="Champs";
$LANG['rulesengine'][13]="Valeur";
$LANG['rulesengine'][14]="Condition";
$LANG['rulesengine'][15]="Motif";
$LANG['rulesengine'][16]="Critère";
$LANG['rulesengine'][17]="Règles";
$LANG['rulesengine'][18]="Règles d'affectation d'un ordinateur à une entité";
$LANG['rulesengine'][19]="Règles d'affectation d'entité et de droits";
$LANG['rulesengine'][20]="Règles appliquées";
$LANG['rulesengine'][21]="Règles applicables dans les sous-entités";
$LANG['rulesengine'][22]="Assigner";
$LANG['rulesengine'][23]="Règles locales";
$LANG['rulesengine'][24]="Choix du type de règle";
$LANG['rulesengine'][25]="Nom de l'ordinateur";
$LANG['rulesengine'][26]="expression rationnelle vérifie";
$LANG['rulesengine'][27]="expression rationnelle ne vérifie pas";
$LANG['rulesengine'][28]="Règles métier pour les tickets";
$LANG['rulesengine'][29]="Liste des règles";
$LANG['rulesengine'][30]="Action";
$LANG['rulesengine'][33]="Dictionnaire des intitulés";
$LANG['rulesengine'][35]="Dictionnaire logiciel";
$LANG['rulesengine'][36]="Dictionnaire des fabricants";
$LANG['rulesengine'][37]="Règles d'affectation d'une catégorie aux logiciels";
$LANG['rulesengine'][38]="Recalculer";
$LANG['rulesengine'][40]="la catégorie";
$LANG['rulesengine'][41]="Validation";
$LANG['rulesengine'][42]="ET";
$LANG['rulesengine'][43]="OU";
$LANG['rulesengine'][45]="Assigner valeur depuis expression rationnelle";
$LANG['rulesengine'][46]="Assigner : matériel sur IP";
$LANG['rulesengine'][47]="Assigner : matériel sur nom + domaine";
$LANG['rulesengine'][48]="Assigner matériel";
$LANG['rulesengine'][49]="Assigner : matériel sur adresse MAC";

$LANG['rulesengine'][50]="Dictionnaire des modèles d'ordinateurs";
$LANG['rulesengine'][51]="Dictionnaire des modèles de moniteurs";
$LANG['rulesengine'][52]="Dictionnaire des modèles de téléphones";
$LANG['rulesengine'][53]="Dictionnaire des modèles de périphériques";
$LANG['rulesengine'][54]="Dictionnaire des modèles d'imprimantes";
$LANG['rulesengine'][55]="Dictionnaire des modèles de matériels réseaux";
$LANG['rulesengine'][56]="Modèles";


$LANG['rulesengine'][60]="Dictionnaire des types d'ordinateurs";
$LANG['rulesengine'][61]="Dictionnaire des types de moniteurs";
$LANG['rulesengine'][62]="Dictionnaire des types de téléphones";
$LANG['rulesengine'][63]="Dictionnaire des types de périphériques";
$LANG['rulesengine'][64]="Dictionnaire des types d'imprimantes";
$LANG['rulesengine'][65]="Dictionnaire des types de matériels réseaux";
$LANG['rulesengine'][66]="Types";
$LANG['rulesengine'][67]="Dictionnaire des systèmes d'exploitation";
$LANG['rulesengine'][68]="Dictionnaire des service packs";
$LANG['rulesengine'][69]="Dictionnaire des versions";
$LANG['rulesengine'][70]="Règles d'affectation des tickets ouverts par email";

$LANG['rulesengine'][76]="Rejouer le dictionnaire";
$LANG['rulesengine'][77]="Dictionnaires";
$LANG['rulesengine'][78]="Version";
$LANG['rulesengine'][79]="Ajouter le résultat de l'expression rationnelle";
$LANG['rulesengine'][80]="Dictionnaire général";
$LANG['rulesengine'][81]="Résultat de la règle";
$LANG['rulesengine'][82]="Détail du résultat";
$LANG['rulesengine'][83]="Il est possible d'affecter le résultat d'une expression rationnelle en utilisant la chaine #0";
$LANG['rulesengine'][84]="Tester le moteur de règles";
$LANG['rulesengine'][85]="Résultat de l'expression rationnelle";
$LANG['rulesengine'][86]="Catégorie des logiciels supprimés par le dictionnaire";
$LANG['rulesengine'][87]="Logiciel mis dans la corbeille par le dictionnaire GLPI";


$LANG['rulesengine'][90]="Traitement en cours...";
$LANG['rulesengine'][91]="Traitement terminé.";
$LANG['rulesengine'][92]="Avertissement avant de rejouer le dictionnaire";
$LANG['rulesengine'][93]="Attention ! Cette opération peut mettre à la corbeille des logiciels fusionnés.<br>Pensez à prévenir vos utilisateurs.";
$LANG['rulesengine'][94]="FUSION";
$LANG['rulesengine'][95]="Choix d'un fabricant";
$LANG['rulesengine'][96]="Rejouer le dictionnaire sur le(s) fabricant(s)<br> ( ----- = Tous)";
$LANG['rulesengine'][97]="Aucun élément à tester";

$LANG['rulesengine'][100]="Informations sur le cache";
$LANG['rulesengine'][102]="Nom de la règle";
$LANG['rulesengine'][103]="Objets en cache";
$LANG['rulesengine'][104]="Valeur originale";
$LANG['rulesengine'][105]="Valeur modifiée";
$LANG['rulesengine'][106]="Inchangé(e)";
$LANG['rulesengine'][107]="Inactive";
$LANG['rulesengine'][108]="original";

$LANG['rulesengine'][110]="Affectation de droits";
$LANG['rulesengine'][111]="Affectation d'entités";
$LANG['rulesengine'][112]="Affectation de droits et d'entités";

$LANG['rulesengine'][120]="Le moteur s'arrête à la première règle vérifiée.";
$LANG['rulesengine'][121]="Le moteur traite toutes les règles.";
$LANG['rulesengine'][122]="Le moteur transmet le résultat d'une règle aux suivantes.";

$LANG['rulesengine'][130]="Entité depuis LDAP";
$LANG['rulesengine'][131]="Entité depuis TAG";
$LANG['rulesengine'][132]="Ignorer l'import";

$LANG['rulesengine'][133]="Entité depuis domaine";
$LANG['rulesengine'][134]="Refuser email (pas de réponse par email)";
$LANG['rulesengine'][135]="Refuser email (avec réponse email)";
$LANG['rulesengine'][138]="Critères LDAP";
$LANG['rulesengine'][140]="Ajout d'un critère";
$LANG['rulesengine'][142]="Liste des emails non importés";
$LANG['rulesengine'][144]="Entité depuis profil de l'utilisateur";
$LANG['rulesengine'][145]="Utilisateur possédant un seul profil";
$LANG['rulesengine'][146]="Utilisateur possédant le profil";
$LANG['rulesengine'][147]="Utilisateur possédant une seule fois le profil";
$LANG['rulesengine'][148]="Domaine de messagerie connu";

$LANG['rulesengine'][150]="Les règles affectées à l'entité ont été désactivées.";

$LANG['search'][0]="Recherche";
$LANG['search'][1]="pour tous";
$LANG['search'][2]="contient";
$LANG['search'][4]="trié par";
$LANG['search'][8]="Date début";
$LANG['search'][9]="Date fin";
$LANG['search'][10]="dans";
$LANG['search'][11]="Éléments visualisés";
$LANG['search'][12]="Spécifier une date de fin";
$LANG['search'][15]="Pas d'élément trouvé";
$LANG['search'][16]="Au moins";
$LANG['search'][17]="Ajouter un critère de recherche";
$LANG['search'][18]="Supprimer un critère de recherche";
$LANG['search'][19]="Ajouter un critère global de recherche";
$LANG['search'][20]="Supprimer un critère global de recherche";


$LANG['setup'][0]="Intitulés";
$LANG['setup'][2]="Ajouter utilisateur...";
$LANG['setup'][3]="Liaison annuaire LDAP";
$LANG['setup'][4]="Types d'ordinateurs";
$LANG['setup'][5]="Système d'exploitation";
$LANG['setup'][6]="Personnalisation";
$LANG['setup'][9]="Interface réseau";
$LANG['setup'][10]="Ordre d'affichage du nom complet";
$LANG['setup'][14]="Email";
$LANG['setup'][18]="Identifiant";
$LANG['setup'][19]="Mot de passe";
$LANG['setup'][20]="Confirmation mot de passe";
$LANG['setup'][21]="Erreur : les deux mots de passe ne sont pas identiques";
$LANG['setup'][35]="MHz";
$LANG['setup'][39]="Suivis privés par défaut";
$LANG['setup'][40]="Tâches privées par défaut";
$LANG['setup'][41]="Langue";
$LANG['setup'][42]="Types de matériels réseau";
$LANG['setup'][43]="Types d'imprimantes";
$LANG['setup'][44]="Types de moniteurs";
$LANG['setup'][45]="Types de boitiers";
$LANG['setup'][46]="Valeur par défaut";
$LANG['setup'][47]="Format d'affichage des graphiques pour les statistiques";
$LANG['setup'][48]="Valeurs par défaut";

$LANG['setup'][62]="Sélectionnez la catégorie à configurer";
$LANG['setup'][63]="Attention vous êtes sur le point de supprimer un intitulé utilisé pour un ou plusieurs éléments.";
$LANG['setup'][64]="Si vous confirmez la suppression, les éléments utilisant cet intitulé se verront attribuer un champ vide";
$LANG['setup'][65]="Vous pouvez aussi remplacer toutes les occurrences de cet intitulé par un autre :";
$LANG['setup'][67]="Authentifications externes";
$LANG['setup'][69]="Types de périphériques";
$LANG['setup'][70]="Configuration générale";
$LANG['setup'][71]="Firmware";
$LANG['setup'][73]="Prise réseau";
$LANG['setup'][74]="Vous ne pouvez pas supprimer cet élément car il possède des sous-éléments";
$LANG['setup'][75]="Comme enfant de";
$LANG['setup'][79]="Catégorie des tickets";
$LANG['setup'][80]="Types de tiers";
$LANG['setup'][81]="Rubriques des documents";
$LANG['setup'][82]="Types de contacts";
$LANG['setup'][83]="Statut des matériels";
$LANG['setup'][84]="Types de cartouches";
$LANG['setup'][85]="Types de contrats";
$LANG['setup'][86]="Types de mémoire";
$LANG['setup'][87]="Catégorie de la base de connaissances";
$LANG['setup'][88]="Réseau";
$LANG['setup'][89]="Domaine";
$LANG['setup'][90]="VLANs";
$LANG['setup'][91]="Modèles d'ordinateurs";
$LANG['setup'][92]="Types de consommables";
$LANG['setup'][93]="Interfaces (Disque Dur, ...)";
$LANG['setup'][94]="Modèles de moniteurs";
$LANG['setup'][95]="Modèles de matériels réseau";
$LANG['setup'][96]="Modèles d'imprimantes";
$LANG['setup'][97]="Modèles de périphériques";
$LANG['setup'][98]="Catégorie des tâches";
$LANG['setup'][99]="Code du bâtiment";
$LANG['setup'][100]="Code de la pièce";
$LANG['setup'][101]="Nombre maximum d'actions automatiques simultanées (exécution CLI)";
$LANG['setup'][102]="Niveau de journalisation";
$LANG['setup'][103]="1- Critique (erreur de connexion seulement)";
$LANG['setup'][104]="2- Sévère (Non utilisée)";
$LANG['setup'][105]="3- Important (connexions réussies)";
$LANG['setup'][106]="4- Notices (Ajout, suppression, tracking)";
$LANG['setup'][107]="5- Complet (Tout)";
$LANG['setup'][109]="Temps en jours de conservation des journaux systèmes (0 pour infini)";
$LANG['setup'][110]="Montrer les nouveaux tickets sur la page d'accueil";
$LANG['setup'][111]="Nombre maximum de résultats de la recherche à afficher par page";
$LANG['setup'][112]="Nombre de caractères maximum pour les listes déroulantes";
$LANG['setup'][113]="Langue par défaut";
$LANG['setup'][114]="Couleurs des priorités";
$LANG['setup'][115]="Seuil d'alerte par défaut pour les cartouches et les consommables";
$LANG['setup'][116]="Assigner automatiquement les tickets au responsable technique";
$LANG['setup'][117]="Autoriser la consultation anonyme de la FAQ";
$LANG['setup'][118]="Texte sur la page de connexion";
$LANG['setup'][119]="Affichage";
$LANG['setup'][120]="Utiliser l'affichage dynamique pour les listes déroulantes et les champs texte";
$LANG['setup'][121]="Caractère pour forcer l'affichage complet des listes déroulantes (joker)";
$LANG['setup'][122]="Nombre maximum d'éléments à afficher dans les listes déroulantes quand le joker n'est pas invoqué";
$LANG['setup'][123]="Ne pas utiliser l'affichage dynamique si le nombre d'éléments est inférieur à";
$LANG['setup'][124]="Ajout automatique des utilisateurs à partir des sources externes d'authentification";
$LANG['setup'][125]="... Depuis une source externe";
$LANG['setup'][126]="Ajouter directement un utilisateur d'une source externe";
$LANG['setup'][127]="Complétion automatique des champs textes";
$LANG['setup'][128]="Format des dates";
$LANG['setup'][129]="Montrer les ID GLPI";
$LANG['setup'][130]="Temps en jours de conservation des journaux";
$LANG['setup'][132]="Afficher le nom complet dans les listes déroulantes arborescentes";
$LANG['setup'][133]="Activer le mode OCSNG";
$LANG['setup'][134]="Mode OCSNG";
$LANG['setup'][135]="Normal";
$LANG['setup'][136]="Traduction";
$LANG['setup'][137]="Debug";
$LANG['setup'][138]="Utiliser GLPI en Mode";
$LANG['setup'][139]="Général";
$LANG['setup'][140]="Types";
$LANG['setup'][145]="Os";
$LANG['setup'][147]="Affichage dynamique";
$LANG['setup'][148]="Pas pour les horaires";
$LANG['setup'][149]="Nombre de décimales pour les montants";
$LANG['setup'][150]="Format des nombres";
$LANG['setup'][154]="Basedn";
$LANG['setup'][155]="DN du compte (pour les connexions non anonymes)";
$LANG['setup'][156]="Mot de passe du compte (pour les connexions non anonymes)";
$LANG['setup'][157]="L'extension LDAP de votre parseur PHP n'est pas installée";
$LANG['setup'][158]="Impossible d'utiliser LDAP comme source de connexion externe";
$LANG['setup'][159]="Filtre de connexion";
$LANG['setup'][162]="IMAP/POP configuration";
$LANG['setup'][164]="Nom domaine IMAP/POP <br>(email de type identifiant@domaine)";
$LANG['setup'][165]="L'extension IMAP de votre parseur PHP n'est pas installée";
$LANG['setup'][166]="Impossible d'utiliser IMAP/POP comme source de connexion externe";
$LANG['setup'][167]="Liaisons GLPI/Annuaire LDAP";
$LANG['setup'][168]="Options de connexion";
$LANG['setup'][169]="Dossier des messages (optionnel, souvent INBOX)";
$LANG['setup'][170]="Chaîne de connexion";
$LANG['setup'][171]="Port (optionnel)";
$LANG['setup'][172]="Port (par défaut 389)";
$LANG['setup'][174]="Hôte CAS";
$LANG['setup'][175]="Port";
$LANG['setup'][176]="Répertoire de base (optionnel)";
$LANG['setup'][177]="CAS configuration";
$LANG['setup'][178]="L'extension CURL ou DOMXML de votre parseur PHP n'est pas installée";
$LANG['setup'][179]="Impossible d'utiliser CAS comme source de connexion externe";
$LANG['setup'][180]="Utiliser TLS";
$LANG['setup'][181]="Fonction ldap_start_tls inexistante";
$LANG['setup'][182]="Addresse web de retour à la déconnexion (logout)";
$LANG['setup'][185]="Traceurs dans fichiers (SQL, mail, action automatique...)";
$LANG['setup'][186]="Fuseau horaire";
$LANG['setup'][190]="Certificat x509";
$LANG['setup'][191]="Attribut mail pour x509";
$LANG['setup'][192]="Activé";
$LANG['setup'][193]="Champ de stockage de l'identifiant dans la variable _SERVER";
$LANG['setup'][194]="Récupération d'informations complémentaires via un annuaire LDAP";
$LANG['setup'][195]="Conserver le statut";
$LANG['setup'][196]="Effacer le statut";
$LANG['setup'][197]="Prendre le statut de l'ordinateur";
$LANG['setup'][198]="Prendre le statut";
$LANG['setup'][199]="Supprimer le domaine des identifiants de la forme identifiants@domaine";
$LANG['setup'][200]="Infini";

$LANG['setup'][201]="Configuration des suivis par emails et des alertes";
$LANG['setup'][202]="Activer le suivi par email";
$LANG['setup'][203]="Courriel de l'administrateur";
$LANG['setup'][204]="Signature des messages";
$LANG['setup'][205]="Mail de test envoyé à l'administrateur";
$LANG['setup'][206]="Échec de l'envoi du mail de test à l'administrateur";
$LANG['setup'][207]="Courriel de réponse (si nécessaire)";
$LANG['setup'][217]="La fonction mail PHP  n'existe pas ou est désactivée sur votre système";
$LANG['setup'][218]="L'utilisation d'un serveur SMTP est indispensable";
$LANG['setup'][219]="Autoriser les ouvertures de tickets anonymes (helpdesk.html, collecteur)";
$LANG['setup'][221]="Date de début de l'exercice fiscal";
$LANG['setup'][223]="Limite des horaires pour le planning";
$LANG['setup'][227]="Addresse web de l'application";
$LANG['setup'][228]="Champ de l'identifiant";
$LANG['setup'][229]="Envoyer un mail de test à l'administrateur";
$LANG['setup'][231]="Mode d'envoi des mails";
$LANG['setup'][232]="Hôte SMTP";
$LANG['setup'][234]="Identifiant (login) SMTP (optionnel)";
$LANG['setup'][235]="Mot de passe SMTP (optionnel)";
$LANG['setup'][236]="Ancien technicien chargé du ticket";
$LANG['setup'][237]="Administrateur";
$LANG['setup'][239]="Technicien chargé du ticket";
$LANG['setup'][240]="Options de notification";
$LANG['setup'][241]="Aucun critère personnel. Voulez vous créer vos paramètres personnels ?";
$LANG['setup'][242]="Options des alertes";
$LANG['setup'][243]="Alertes sur les consommables";
$LANG['setup'][244]="Alertes sur les cartouches";
$LANG['setup'][245]="Fréquence de rappel";
$LANG['setup'][246]="Alertes sur les contrats";
$LANG['setup'][247]="Alertes sur les informations financières";
$LANG['setup'][248]="Groupe chargé du ticket";
$LANG['setup'][249]="Groupe demandeur";
$LANG['setup'][250]="Affichage recherche par défaut";
$LANG['setup'][252]="Sélectionnez les éléments à afficher par défaut";
$LANG['setup'][253]="Filtre pour la recherche dans les groupes";
$LANG['setup'][254]="Type de recherche";
$LANG['setup'][255]="Attribut des groupes contenant les utilisateurs";
$LANG['setup'][256]="Dans les utilisateurs";
$LANG['setup'][257]="Dans les groupes";
$LANG['setup'][258]="Utilisateurs & groupes";
$LANG['setup'][259]="Appartenance à des groupes";
$LANG['setup'][260]="Attribut utilisateur indiquant ses groupes";
$LANG['setup'][261]="DN du groupe";
$LANG['setup'][262]="Utiliser le DN pour la recherche";
$LANG['setup'][263]="Filtre de recherche des utilisateurs";
$LANG['setup'][264]="Alertes sur expiration des licences";
$LANG['setup'][271]="Restreindre la gestion des moniteurs";
$LANG['setup'][272]="Restreindre la gestion des périphériques";
$LANG['setup'][273]="Restreindre la gestion des téléphones";
$LANG['setup'][274]="pour ajout manuel";
$LANG['setup'][275]="Restreindre la gestion des imprimantes";
$LANG['setup'][280]="Mise à jour automatique des éléments connectés directement aux ordinateurs";
$LANG['setup'][281]="Lors de la connexion ou mise à jour";
$LANG['setup'][282]="Lors de la déconnexion";
$LANG['setup'][283]="Copier";
$LANG['setup'][284]="Effacer";
$LANG['setup'][285]="Ne pas copier";
$LANG['setup'][286]="Ne pas effacer";
$LANG['setup'][300]="Vérifier si une nouvelle version est disponible";
$LANG['setup'][301]="Une nouvelle version est disponible :";
$LANG['setup'][302]="Vous la trouverez sur le site GLPI-PROJECT.org";
$LANG['setup'][303]="Vous disposez de la dernière version disponible";
$LANG['setup'][304]="Connexion au site impossible. Si vous utilisez un proxy, configurez le.";
$LANG['setup'][306]="Vérifier la présence de mises à jour";
$LANG['setup'][305]="Tous les jours";
$LANG['setup'][307]="Jamais";
$LANG['setup'][308]="Toutes les semaines";
$LANG['setup'][309]="Tous les mois";
$LANG['setup'][310]="Connexion au site impossible.";
$LANG['setup'][311]="Connexion au serveur proxy impossible";
$LANG['setup'][312]="Pas de données disponible sur le site";
$LANG['setup'][313]="Attention : il n'y a plus de valeur par défaut";
$LANG['setup'][350]="Liaison avec les matériels pour la création de tickets";
$LANG['setup'][351]="Tous les matériels";
$LANG['setup'][352]="Matériels associables à un ticket";
$LANG['setup'][360]="Champs automatiques (marqués par *)";
$LANG['setup'][400]="Configuration du proxy";
$LANG['setup'][407]="Lien Aide dans l'interface simplifiée";
$LANG['setup'][408]="Lien Aide dans l'interface standard";
$LANG['setup'][409]="Rubrique par défaut pour les documents liés aux tickets";
$LANG['setup'][503]="Modèles de téléphones";
$LANG['setup'][504]="Types de téléphones";
$LANG['setup'][505]="Types d'alimentation téléphone";
$LANG['setup'][601]="Valeur LDAP";
$LANG['setup'][602]="Connexion à la base de données OCSNG";
$LANG['setup'][603]="Ajouter un utilisateur";
$LANG['setup'][604]="Associer à un groupe";
$LANG['setup'][606]="Ajout impossible. L'utilisateur existe déjà.";
$LANG['setup'][607]="Associer à un profil";
$LANG['setup'][608]="Logiciels associables à un ticket par défaut";
$LANG['setup'][609]="Ajout impossible. Le serveur OCSNG existe déjà.";

$LANG['setup'][610]="Titre du ticket obligatoire";
$LANG['setup'][611]="Contenu du ticket obligatoire";
$LANG['setup'][612]="Catégorie du ticket obligatoire";
$LANG['setup'][613]="Ajouter un utilisateur d'un annuaire LDAP qui n'a pas d'habilitation";
$LANG['setup'][614]="Modification du login impossible. Un utilisateur existe déjà.";
$LANG['setup'][615]="Cycle de vie des tickets";
$LANG['setup'][616]="Depuis \ Vers";

$LANG['setup'][620]="Liaison";

$LANG['setup'][621]="Filtre de recherche des entités";
$LANG['setup'][622]="Attribut représentant l'entité";
$LANG['setup'][623]="Importation des entités depuis un annuaire LDAP";

$LANG['setup'][650]="PHP";
$LANG['setup'][651]="SMTP";
$LANG['setup'][652]="SMTP+SSL";
$LANG['setup'][653]="SMTP+TLS";

$LANG['setup'][660]="Serveur mail";
$LANG['setup'][661]="Configuration des notifications impossible : veuillez configurer le suivi par email dans la configuration ci-dessus.";

$LANG['setup'][703]="Générale";
$LANG['setup'][704]="Notifications";
$LANG['setup'][707]="Alertes sur les réservations";
$LANG['setup'][708]="Alertes sur les tickets non fermés depuis";

$LANG['setup'][720]="Informations système";
$LANG['setup'][721]="Informations sur le système, l'installation et la configuration";
$LANG['setup'][722]="A copier/coller lors d'une demande d'assistance";

$LANG['setup'][731]="Valeur de la configuration générale";
$LANG['setup'][732]="Domaine de messagerie";

//MySQL Replicate
$LANG['setup'][800]="Réplicat MySQL";
$LANG['setup'][801]="Activer le réplicat MySQL";
$LANG['setup'][802]="Base";
$LANG['setup'][803]="Écart entre le maître et l'esclave";
$LANG['setup'][806]="Durée maximum de désynchronisation (en minutes)";
$LANG['setup'][807]="La base de donnée esclave est désynchronisée. L'écart est de";
$LANG['setup'][808]="Base de données esclave désynchronisée !";
$LANG['setup'][809]="Réplicat MySQL : lecture seule";
$LANG['setup'][810]="Désynchronisation du réplicat MySQL";

$LANG['software'][1]="Version d'achat";
$LANG['software'][2]="Version d'utilisation";
$LANG['software'][3]="Licences affectées et non installées";
$LANG['software'][4]="Illimité";
$LANG['software'][5]="Versions";
$LANG['software'][6]="Editeur";
$LANG['software'][7]="Ajouter une version";
$LANG['software'][8]="Ajouter une licence";
$LANG['software'][11]="Licences";
$LANG['software'][17]="logiciel(s) installé(s)";
$LANG['software'][19]="Installations";
$LANG['software'][20]="Restant";
$LANG['software'][28]="OEM";
$LANG['software'][29]="Mise à jour";
$LANG['software'][30]="Types de licences";
$LANG['software'][32]="Expiration";
$LANG['software'][44]="Installation d'un logiciel";
$LANG['software'][45]="Désinstallation d'un logiciel";
$LANG['software'][46]="Associable à un ticket";
$LANG['software'][47]="Regroupement";
$LANG['software'][48]="Regrouper";
$LANG['software'][49]="Logiciel mis dans la corbeille après regroupement";
$LANG['software'][50]="Affectée à l'ordinateur";
$LANG['software'][51]="Le nombre doit être 1 pour pouvoir affecter";

$LANG['softwarecategories'][2]="Logiciels sans catégorie";
$LANG['softwarecategories'][3]="Déplier les logiciels sans catégorie";
$LANG['softwarecategories'][4]="Déplier les logiciels appartenant à une catégorie";
$LANG['softwarecategories'][5]="Catégorie de logiciels";

$LANG['state'][0]="Statut";
$LANG['state'][6]="Type de matériel";
$LANG['state'][7]="Pas de matériel trouvé";
$LANG['state'][11]="Synthèse";

$LANG['stats'][0]="Sélectionnez les statistiques à visualiser";
$LANG['stats'][1]="Globales";
$LANG['stats'][2]="Aucun élément à afficher";
$LANG['stats'][3]="Par Intitulé";
$LANG['stats'][5]="Nombre de tickets ouverts";
$LANG['stats'][6]="Délai moyen de traitement du ticket";
$LANG['stats'][7]="Voir les graphiques";
$LANG['stats'][11]="Nombre de tickets fermés";
$LANG['stats'][13]="Nombre de tickets";
$LANG['stats'][15]="Durée moyenne de traitement du ticket";
$LANG['stats'][16]="Nom du technicien";
$LANG['stats'][20]="Nom d'utilisateur";
$LANG['stats'][23]="Pas de statistiques disponibles";
$LANG['stats'][25]="Durée réelle moyenne de traitement du ticket";
$LANG['stats'][27]="Durée réelle totale de traitement des tickets";
$LANG['stats'][30]="Délai moyen de prise en compte du ticket";
$LANG['stats'][31]="Jour(s)";
$LANG['stats'][33]="Min(s)";
$LANG['stats'][34]="Sec(s)";
$LANG['stats'][35]="Ticket(s)";
$LANG['stats'][44]="Nom du fournisseur";
$LANG['stats'][45]="Par matériel";
$LANG['stats'][47]="Par ticket";
$LANG['stats'][48]="(assigné)";
$LANG['stats'][49]="(suivis)";

$LANG['title'][5]="Base de connaissances";
$LANG['title'][6]="Matériels Réseau";
$LANG['title'][9]="Statuts des matériels";
$LANG['title'][10]="Suivi des tickets";
$LANG['title'][13]="Informations Utilisateur";
$LANG['title'][14]="Sources d'authentification externes";
$LANG['title'][24]="Assistance";
$LANG['title'][26]="Principal";
$LANG['title'][27]="Connexions";
$LANG['title'][28]="Tickets";
$LANG['title'][30]="Composants";
$LANG['title'][33]="Liens externes";
$LANG['title'][34]="Liens";
$LANG['title'][37]="Notes";
$LANG['title'][38]="Historique";
$LANG['title'][40]="Notes personnelles et publiques";
$LANG['title'][42]="Modification Massive";
$LANG['title'][43]="Registre";

$LANG['tracking'][1]="Mes matériels";
$LANG['tracking'][2]="Ou recherche complète";
$LANG['tracking'][3]="Dates invalides. Modification annulée.";
$LANG['tracking'][4]="Votre ticket ne contient pas d'urgence, veuillez corriger.";
$LANG['tracking'][8]="Votre ticket ne contient pas de description, veuillez corriger.";
$LANG['tracking'][9]="Par défaut pour les tickets";
$LANG['tracking'][10]="Par défaut pour les collecteurs";
$LANG['tracking'][24]="Document Ticket";
$LANG['tracking'][29]="Nombre";
$LANG['tracking'][30]="Nouveaux";
$LANG['tracking'][31]="En cours (attribués)";
$LANG['tracking'][32]="En cours (planifiés)";
$LANG['tracking'][34]="Directe";
$LANG['tracking'][35]="Écrite";
$LANG['tracking'][37]="Conserver les tickets à la purge d'un élément de l'inventaire";
$LANG['tracking'][38]="Un mail de suivi a été envoyé à";
$LANG['tracking'][39]="Visible dans l'interface simplifiée";

$LANG['transfer'][1]="Transfert";
$LANG['transfer'][3]="si n'est plus utilisé";
$LANG['transfer'][4]="Vider la liste des éléments à transférer";
$LANG['transfer'][5]="Vous pouvez continuer d'ajouter des éléments à transférer ou transférer dès maintenant ces éléments";
$LANG['transfer'][6]="Pensez à faire une sauvegarde avant de transférer des éléments.";
$LANG['transfer'][7]="Éléments à transférer";
$LANG['transfer'][8]="Mode de transfert";

$LANG['update'][88]="Votre version de la base de données n'est pas compatible avec la version des fichiers  installés. Une mise à jour est nécessaire.";
$LANG['update'][89]="Vous tenter d'utiliser GLPI avec des fichiers d'une version antérieure à la version de la base de données. Veuillez installer les fichiers GLPI dans la  version correspondante à votre base de données.";
$LANG['update'][90]="Erreur durant la mise à jour de la base de données";
$LANG['update'][91]="Attention !";
$LANG['update'][92]="Vous allez mettre à jour votre base de données GLPI ayant pour nom :";
$LANG['update'][93]="Connexion à la base de données réussie";
$LANG['update'][94]="La mise à jour est réussie, votre base de données est actualisée";
$LANG['update'][95]="La connexion à la base de données a échouée, vérifiez les paramètres de connexion figurant dans le fichier config_db.php";
$LANG['update'][96]="Tous vos utilisateurs ayant précédemment les droits 'admin' se sont vu attribuer les droits 'super-admin' avec l'ajout de ce nouveau type d'utilisateur";
$LANG['update'][105]="Impossible d'accéder à la mise à jour de cette façon !!";
$LANG['update'][106]="Retourner à GLPI";
$LANG['update'][107]="Vous devez maintenant procéder à la mise à jour de l'ancien contenu de votre base de données";
$LANG['update'][130]="Mise à jour des lieux";
$LANG['update'][131]="La nouvelle structure est hiérarchique";
$LANG['update'][132]="Si vous utilisiez un caractère de séparation vous pouvez l'indiquer pour automatiser la génération de la hiérarchie.";
$LANG['update'][133]="Vous pouvez aussi spécifier un lieu de base qui inclura tous les lieux générés.";
$LANG['update'][134]="Caractère de séparation";
$LANG['update'][135]="Lieu racine";
$LANG['update'][136]="Voici la nouvelle hiérarchie générée. Si elle vous convient, vous pouvez la valider.";
$LANG['update'][137]="Nouvelle hiérarchie";
$LANG['update'][138]="Lieux actuels";
$LANG['update'][139]="Optimisation des tables";
$LANG['update'][140]="Création d'index";
$LANG['update'][141]="Modification du schéma";
$LANG['update'][142]="Redressement des données";

$LANG['users'][1]="Titre";
$LANG['users'][2]="Catégorie";

$LANG['validation'][0]="Validation";
$LANG['validation'][1]="Envoyer une demande de validation";
$LANG['validation'][2]="Etat";
$LANG['validation'][3]="Date de la demande";
$LANG['validation'][4]="Date de la validation";
$LANG['validation'][5]="Commentaire de la demande";
$LANG['validation'][6]="Commentaire de la validation";
$LANG['validation'][7]="Validation(s) pour le ticket";
$LANG['validation'][9]="En attente de validation";
$LANG['validation'][10]="Refusée";
$LANG['validation'][11]="Acceptée";
$LANG['validation'][12]="Non soumis à validation";
$LANG['validation'][13]="Demande de validation envoyée à";
$LANG['validation'][15]="Ticket attendant votre validation";
$LANG['validation'][16]="Facultatif en cas d'acceptation";
$LANG['validation'][18]="Demandeur de la validation";
$LANG['validation'][19]="Validation acceptée";
$LANG['validation'][20]="Validation refusée";
$LANG['validation'][21]="Valideur";
$LANG['validation'][23]="L'utilisateur choisi n'a pas d'adresse email renseignée. La demande a été créée mais l'envoi de l'email a échoué.";
$LANG['validation'][25] = "Statut global de la validation";
$LANG['validation'][26]="Demande de validation";
$LANG['validation'][27]="Une demande de validation a été soumise";
$LANG['validation'][28]="Statut de la demande de validation";
$LANG['validation'][29]="En cas de refus de validation, vous devez indiquer un motif";
$LANG['validation'][30]="Suppression de la demande de validation à";
$LANG['validation'][31]="Mise à jour de la demande de validation à";
$LANG['validation'][32]="Une réponse à une demande de validation a été effectuée";
$LANG['validation'][33]="Des tickets sont en attente de votre validation";

?>
